
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python FinTech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']


def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    pass


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    pass


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    pass


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    pass


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    pass


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\x88*\x00\x00PYARMOR\x00\x00\x03\x08\x00U\r\r'
        b'\n\t0\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00H*\x00\x00\x00\x00\x00\x00)\xa9[$A0J\xe8\xb8\x86a_/o\xc0~\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2o>\x8e\xc4\xaa=\x1fb\xf6\x9f\xd0K\x8d\xb7\xbf\x9a\xf6~;\xb9\x1az-\xa0\xa4x\xf4\xfdC\xa5\xd8\xc2K\x00\x18)f\xe8\xe0X\xb0\xd1u\xcal\xd8\xeaY\x11\xc8\xa4\x84\r'
        b"p\xbd\xbe^\x1f$*\xed'*\xbc\x86\xe7\xd9\xb6DW\x1b\x10\xfe\\\xfd;c\x1a\xfe\x18J\xb7.,\r\x94\r(\x17:\xd6\xc3md\x11\xcd\xb3\xc4#^I%\xac\x8cx\xb4\xff)\x88A\x8a\xd6d~\x8b\x1c\xd2"
        b'\xa7\xbdv&\xe7p9iBj\xaa>\xcb\x92Tf\xb9\xe9\x8d\xf8\xfbD\xde_\x98\xf6\xf4\xb3\xc8\xc6\xc9W\xd2\x84\xc11%\\\xc6\x99;>\\J\x10I\xd23\xb5\x0c /0\xa3\xdd2\xa9%\x03\x15\xd7gv\xe9'
        b'\xf1+\x88\xaf\xc3\xe5M\x10\xb6GuL\xfez\nG\xe9\\[\xbdF\x83\x08\xe5v\xc5\xed\xf3\x13\xddA\x06\x9f\x97o\x08\xbb\x89%\x93\x03U}\xfc\x8d\xac\xecx\x04\xee\xb05\xe4\xd8\xa1\xc2\xb5\x9fk\xe3K\xe3\xf8\xc6'
        b'~S\xb0:t-\x91\xe5S\xbf\xba\xf4q\xe7{~8Y\xd3X)U\x9f\xe2\xe3\xf8)R\x055#\xae\xef\xdf0\x92LK\x98YV\xa2aTJ\xb3t\xb0\x1a\x9ab\xed\x9eVC\xa0\xe0n\x90\x19m\x84\x19\xa6'
        b'\xab\xd3[\x03\x95v/\xc6\xde\x02\xf8\x1f\x7f\xd4h\xfc\xd7\x9d\x1cW\xad2\xf8\xb7\x0ex\x011\x94\xd7\x12\x9c\x15\x19L>b\x13\xfa\x9bw\xfd3\xcf\xda(\xb2\xe2\xe1\xe7\xd3\x8e~D\xbb\xdb\xe4\xf6\xc1o\xffy\x82\xfd'
        b'\x1d\x05\xfd\xea\xab$\xdb\xd9\xb5\xd0.\xc8\x95Uh\xe0k{\x8fI\x91 \xae[\xf4\xbc\x9d\xc5p\xb5\xf7a\x8d\x15\x1fH\x0c\x95\xbd\xf4 \xb9\tW\xb8\xf6\x19\xab\xe49\xe1\x9c(\x034\t\xbf\xfa\xf1\xcf\xeaf[\x08'
        b'\xf5\xf0M\x08\x02\x82X%\xbb\xe7\x1b\xed\xefv\x90~\xc8\xc6[Y\xc0\x9f\xda\xaf\xfe\xa9c\xc1\xe0\xc6\xac\xc3t\xddu\xba\xa8\t\x04\xf2\xa2\xbf8~\xcb\x86\x92]\xf3h\x82\xd1\xb7\x8b\xbeg\xd8\xeb\x0b\x86x\x0e\x11p'
        b'P\xe3~V\x8e\xdbjt\xd7\x12TBQ\x81d\x02\xd8\x88Pg\x96H\xdf\xa1N\xa2 \x84p\xf9o\x18\xd3{\x02\xba61\x89\xe8\xcb\xca\x19i\xf7\xaegr\xa4\xc8\x1b\xbe\xd0\t8m|zXi\xd8\x8b[4'
        b"E\xfa\x06\xf1y\xa1\xd3\x9cg_~\xe7W\xae\xe2\x15Y%\xba\x94\xd2\xcb\xfe\xdb\xc7;[\x13?\x15\xd8\xa9`\x85U;V\xa67\x87kl\x8f\xb9m\xfa\xd1\xf0\xc3O\x9aO#'\xda\xae\xb4o\r<\x1f\x83\xa9\x87"
        b'\xa3\xe2\x03\x96J\x1bL8\x86\x87q\x8f\xc3\n8H\x9f\xe8B\xb8\xc8\xe6\n\xff\x99\xae\xdcI\xd7p\xf8]\xd3\x80\xd4u\x1a\xe7z~bARO\xc2Ay\xbf\x00\x0f\xb2\xee\x00\xbc=\x17ym\xc5|\x83\xe3\xd5N'
        b"\x9ce\xe1_\x9dI\xaa\x1e\x02B\x18\xf7\x9aI|\x19\x00\xfa\xef\x18\xc0'|\xe6q\x96v;\x12\x01(\xa2\xc6\x1a\xfb}O$\xc6\x03\x19\x8e\xe9\x03\xda\x9c\x97\xda_\xd6~\xd3[\xf1\x17\x9bU\xf7N\x1b\xbb2\xf2O"
        b'\xe4\xa3H\xef\x96Lz\xdf\x94OL\xf7\xb1\x80a\nN\xd4u7Y\x8c\x8a\xa6\xa2\xbb\xde\xc4Z[\xb1\x0fk\xd2\xc3D\x14d\xcb\xfc\x15\xd26\xd7\xda\xfcDL\x07ii\x811l(\x19\xf1\x85\xc5\x9a\xa8\xf3~\x1b'
        b't\xfb\xedF\x9e\t\x91?c\x8fse\xa1\x00V\x1a\x8d/6&\xb1\x064\xa7\xa8\xc0|\'uY\xc4!F\x8b\x91\x0c\xd9Bg\xeaP\xa0\xa2\x95\x95#1\xdb"$b\x9d\x18\xc6\xade\xa2ho{F\xe9\x83&'
        b'uU!0.E\x07\nhz\xf3\xe1j7\xd1m\n m\x0e\r\xad\x14\x8a\xc7GZ\xf0\xe5u1\xc7T\xde\x0e\xfaGN\xdf\x1f7\x8al\xbc\xbd<\xc5\xa8]F\x03\xbf\xc0\xd5\xc1]\xf3i\x88p\xbePDj'
        b'\x84\xc9w\xccy\x08\xfc\xe9\x92\x86\x9e\xb3\xf3z\xb1\x87\x0c\xf3\xc5\x04SJ\xca\xf0Z\xddzj\x1b\xf0\xd6\x1d\x07t\xf3\xd9FD\xd2%\xd1\xecJT\x17\x89\xc56\xe7kp\xcd\xd7\xe8\xfe\xfc\xbe\xf3\x0e\xeaJ\x9e\x86v'
        b'\xe3J\x08y<yY\x9cWGj\xc5\x0c\x07\xc1\xbc\xcd\x1ay\xa4\x8cZ\x0e\x97\xa4zo\x8c\xe8\x13\xa9\xe6p\xf9\x92a:\xfa\x85\x18\x14e\x0f\x91NlT7\x1f*\x8f\xbc\xd7c\x0b\xb1\xc8\xe7\xc1\xecg\xbe!\x96'
        b'\nja\xa1\xbc\n\xc7\xb6\x08c\xfe\xd3.x\x08Mw\xe9x#f\xe6q,4\xee\xf01\xc9\x95\x9f\xef\xaa5b\x82%P\xe6\xd8k\\\x9b\xa3\xaf\xad.\x12W\xff\xd1c\x92\xe2$G:U1\xea\xe6=\xde\xc8'
        b'\xdd\x8b\xa6\xfa\xa8\xb2I\xae\xbe\xdeA.\x8b\xe8S\xe8O\xf6\x19\x0bvh@V\x81\x12\xfa,\x83\xa7\xa6\xfdZ\x1a\xd0\x1f\xe2\xff\xb0\x9f\xbb\x02\x18\xfa\xe5\x83\xb3\xfeb\xf3b\x1f\xb5\xfas\xe4\xb0\xd1?U\x1b\xf8\xa1\xcc'
        b'o\xb0\xb4G\xae\x0c]\x15\xae\x88\xdf\xb1\x81\xe51\x9b\xd9\xc2\xf7v\x82\tW\x8a\xc6\xb0\xe5\xd2\xd8 \xfe\x1b\xb1{I8\x0b\x87)T=\xf6\xd1i\x1b\xef\xb5\xe7\xe9F\xa8\xd5\xa5\x83";\xb20\xd6\x03\xc6\x0e\x9e\xea'
        b'\xea\x17\xcfo\xf5\xc0\xd7+i7$\xb1\x8f\xceI\xf7\x89m|_\xb5\x96;\x97\xd7X$\x16\xcf_\xe3\xb6\xfe\x19%\xb6\x86B\xdd\xc6N\xaf\xe4d\xd7X\x9bB9\xe8\xb1\xde\xce\xfb\xd7(*\x15\xfc\xca\x1e\xed\xdb\xee'
        b'X\xee\xa2\xf8\x02X\xb5\x12qIE\x08Co\xd9v\x91\xe8\xa5"\xf7E\xba\n\xe8\x96Q\\\x01RRY\x9f{\xd7m\x80\t\xd3\xee]\x06\x7fr\xd8\xd1\xef\xdd\xd41\xe6\x04\xfe\xeem\xbc\x19\xe4\xca\x85\xb18\xf3C'
        b"\xbaqL~\xfa\x1d\x13\x95\xa3\x86*F\x98\x8c\x8emMn\xffx\xb6\x90\xbc\xdd\x06\xeau\x8f\xbf\xba\xa1\xc6\xf5\xde\xd9\x92\xe6s\xb0\x9c!\x96\x15\xca\xcc'S\xe5\x9f\xee?\xf56c\xa8\xda\xd3\xbc\x95\xa3t\x12wp"
        b'\x97\'\x8b4\xb1g\x04\x95@\xd3AZ\x85\xf1\xe0\x86d\xc9\xf0k#\xa6OH\xa3\xcd\xeb\xbd\xcd\xf4=V\x9d^\x02\x83\xc1\xaa\xdc\xech}Q\xa5"0\x9a\'$\x9d#\xa0\xa9\xd8D\x9fO\x1c\x87\xc5\xcet\x7f\xa9'
        b'`/C\xde;Z\xd1K\xa0\x04b\x89\x90b{X\xdf\xbb\xc1\xfe/\xf3\xc8g\xc1\xd5\xf5\x04\xff\xb9\xd1,\xfc$\xfe\x06\x1bL\x84\x7f\xb3ny5\x0b\xd7\x14-$e\xa4f\x12\xf1y\xcc/j\xf3\xcc\xd6M\x8a\x1f'
        b'\x9b1\xe1e*m\xbb\t\xea/\xf6*\x8e\xe7\xd0\x96\xe0D6\x08"\x1a\x8c\x0c\xb2\xe4\xc6\xfb\xacq\xe4\xb2\xc5LhhY$q2\xff\xa9\xbd\x13M]z\x80\x1d"9\xe6%\xb6\xe0d\xa8C\x02\x15\xfeV;\xef'
        b"V\xe1\xb5=\x90c\xa8\x15-\x0b=\xf9\x95\x95\x1d\xaa\xdd'z\xa5\x19\xe1y\x80\x08\xd0\rdhB\xde\xa5\xd3o\x85\x1b\xf8\xc9\x81\x10b\x81\xd6\x19\xc4U\x9a\x00K\xe8\xb8\xbba@\x89\xcf>\x99e\xef+R\xf4\x03"
        b'\xd1\x15\x05\x02o\xc5\xf6\x0en\xdd\x82\x1b\x9ex\x82t\x88T\xbb`\x04\xbc\x04\xa0\xd75\x16\x9cy?\xb4\xcb\xf8keT`/\x9b\x92\x90\x11\xb0&U\x1d\x97\x99?\x85\xc1c\x9d\xf0\x98\xda!\xe2\xdeG\xe5h\xa5<'
        b"\x8b\xdcoL\xe7^7:'\r0)xF\x08\xe1E7Fz\x84\x98\x03\x8600k%.5r\xc2@'\xdaB\xbe\xe4\xaf\xed5QP\xc9R\x93\xf1e\x9fWD\x89\xe1\x93\xbc\x98\xa9\xcbsp\xc8Oy\xc8"
        b'\xb9b=-\xca\x07\x05\xfd\xbd\xc5\x972\xcb\xc3\xad|\x1e\x12\xfd\x1bW\x85|A\xf2\xedMOUkT\n\x14\rA=\x1c\x9e>v\r/W\x81\xf3=I\xb3\xed\xfaT-\xa8\xe5\xd7z\xe1\x80\x01\xd6\xb3\xcaF1'
        b'\x0fpC2VG\xack\xb7T\x87\xad\x94U<\xd7k\xbb\x91[N\xf0g`\xa0`\xe9q\xf55#\xec_\tUU\xb5t\xf8\xfd$fx\x88*\x17rQv\x89\x01#PF\xe0z\x89\x08\xbb\xf5-0q\xf4'
        b'\xf5|\x8b+"6i\xcf\xce\x1a3\xc1\xde\x8c\xf5\xdaw"e\xab\xe0j\x879\xa7\xc4+\x11zu\xdd\x7f0\x1f"\x94\x04\xc2\xfco\xfe\xb4q\x97\x9e\xdc\xaa^\xb6\xd7\xafW\xa51\xbc<\xcb\xc1\xf2\x0b\xe6m\xf8\xe2'
        b'\xd1\x87\x81|\xe7\t\x03\xe8q\x18d\xe2\xd7\x9e\xce\x89\xd94\xdb\xfc\xac\x9b\x87w\x99\xd8\xa1\n\xc7\x85\xa3\x90\xf4,\xfb%\xf0\xb4DZlW#\xfe4\xbfXB\xc4\xc4\xd13E\x14{\x00\x89\xa9c\xb9\\\xd6\xbaY'
        b"\x18\xfa\x88Q\xec\xe5\x01Qq\tb\xce\xa26\xc6\x06\xf2\xaa\x8a;\xcb\xfc\x0b \xc0\xff\xc4\xe8\xc30zf\x99'l\x93\xa0Y\x977o\xb4=\xb5\xdd\xb8\xc5\x80\xe2\x7fyR\xef\xa5\x06\xe1\x1f\xb2O\xaf\xd4\x8b\xd3\x80"
        b'\xbb\xd4\xa8\xdf\xc4\xd8\xf1f\xf8\xbd\x85\x93\x7f\xd7g\xb8\xa0Z1g\xf7\xe0)\n\xef\x9d\xbc\xc9^-\xdc\xd0\x82\x13U\x0cW\xa8~\\\xd7\xac\xec\xe8)=\xfco\x0f\xb2\xff\xb6\xc2\xc7\xed0w6\x90\xfd\xe4\xd1\x91Y'
        b'Z\x86}\xf3\x81\xae\xd1\nS\x9c*\xff\xdf\x17II\x93\x07\xda\x88\xb5\x9e\x1a\xa9-N\xb5\xbb\\\x10\xa7\xf4O\xd7\x17]?r\x8b\x8e\x954\xe8\x8f\x9b\xeeM\xcdod\xde|\xb0\xceBh`\xdc&\xe8\xee\x8b\x8d5'
        b"\x04\xe9\x93\x11\xb3\x1f'\xf0\x92\xd7W\t4\xba\xea\xb2'*\xe0\x10sm\\#\xa0\xe5\x07\xd8\xf5\xaf\x02w\xbf\x16{c\x12\x1fE\xe8\x81M\x8b\x01\x05\x99{\xee\xb7i\x0ec\x14\xd0\xae3_\xdc\x00\x14\xd2W2\x93"
        b'\xfd\xab\x81\xc91\n\xa6b\xe3\xeb\x9c\xa9=T\xfc\xeci\x05\x14\x93\xa6v\xc7[\x01\x89\x04\x85\x94\xa9\xae~+\x94D\x16.\xd7y\xe2\xbb2\x02\xc2\xea\xb5>\xa8\x18\xacv\x85\x03\xcd%@Y\xae\xc0\x99\x16\xf0\xed\x19'
        b'\x98D\xfdy\x10t\x99\xfc\xc5\x81(\x1aG\xe4a#\n\xed\xb6\xe8G\x8c\xac\x10F\x80\xc6?\x8fv\xa5\xcd\x83g\x96\xb7\x8d:u\xde\xef\x06U\x01\xf4\xaay wwZ\xe4a\xacK\xf51/t;\x14]q '
        b'\xc4=\x19T\x0el\xc5Cu(\x1a\x83u\xc7u\x12\x04\xf8\x0b\xf5I\x03\xed\xbbt?\xf2\xd2\xd5aKD\xe4\x19\x94k\xdd\xc8\xa1\xdb\xa4a0\xba\xa8\x9d\x13\xf3\xe8\x0f\xa8\x82\xe5K\xef\xc5\xe0\xc9\xcfH\xf0\x9f\xbb\xa5'
        b'J\xe9\xb5?\x99R\xa4\xc1>\xa1b\xb2\x9c\x95h\xf9\x13H^|ccbl\xfa\x94\x8c)\x9a\x17\x88\xccf{8\xd0\x0ev\x03\xe5\xd2L\x1c\x98\x1c\x92\x02\x18\xa6\xa6\xc0\xcdt$[\xd3\xea\xe0F{\xe4\xfb\xc78'
        b'K\x86\xf7\xc1*X\x87\xa3\xce\x8b\\\\\xf7S\xbb-KZ{b\xd3\xd1\x88>\xa5\xd83\x97\xa6\x9bj<\xd4\x1f\x9f\xeb\xb2\xf9\xd9k\xcb\x8b\xf0\x07iog*Be\xa8\xff\x87I\x90\xb5\xa4y\x81c\xa2\x01\x18\\'
        b'@Ww+\xcd\xe1$\xa0\x9e\xb1\xcfv\x0e\xafIF\xca\xbf\xc9\xd2vP1\x14\xb0\x9a\xf6\xae\x07\x02Yr\xe3@]\xd6\xd0a\xdb\x82\xa3\xf7%x\x81A\xb7=\xf6\xbfdf\'U\xd3\x03D\xca/+`\xbf\x85"'
        b'%\xbb\xb2\x14\xa0eU\xa43\xac\xc2{\xbc\xdd\x85\xfePn\xe7L>\x85\xd3\xbbc\xfe\xaf\xbd\xe7e3\xc8\x98:}\xb51\x8a%\x9d\x88\xd9h\xf2\xd3vTY\xaf\x82\x93\xfbP\x0f\x82\xca\xbb\x03\xd9!\xe6\x13\xde\x84'
        b'\xd4yS\xd4F\x08WY,\xf2\xd4\xb5\xbdXS\x14\x17\xd5\x98\x08%=\xbd\x8d4V\x05\x17#\xf1\x0e\n\xffn\x97\xa0/%2\xe3\x14\x12\xa9\x1a\xe4\x16\xb6#\x8c\xf2\x03\xb5\xa5\x01\x8c\x0b\x04@\xab\x9eV1,\x88'
        b'\x96K\x9c\x06\xea\x1b\xb3t\x88\x9cRo?\xf87i\xd7\xe9e\x0en\xea\x88w#0\xd6\x03Q\xc4\x96\xaaV\xa9\xaa\xc8\x16\xe6p\xbe\xeekJ\x17AC\x1f\xf2Y\x97sK!z\xc8u\xf7\xdf\x1f\x83,_w\xa2'
        b"\xa9\x9b&\xbc'\x8b\x9f4\x8e\x06\xdc\xe1\xec\xc8\xfc,sg^'\xd5\xcc\xe2\x88\xdb\xd3\xd1f\x01Lf\xffI\xb7d\xc4\x7f\x0cj\xff\x9c\x92\xe3v\x8c'BZ>>\xebo\xf4\x90R\xec~_\xd7\x0f\x96\x13\x016"
        b'\xd0R\xfb\x95\x03\xb9\x01$\xb4\x89:\xe1q>\x82S\x88\x99\xbc\xf5\x8c\xf7\x01\x9b/\xb6_d\xeev\xd6&\xe5\x17w\xc1v\xd1\xea\xce}\xea(\xb7\xaa\xbb#\xe6\xf7\xe6\xe2bC+D\xa6\xf5\xc5\xa2\xdc\x0f\xbbgK'
        b'I\xa7a\xbfF-;>j\x0c\xd7{\xdd\x81\xb5\xc2{z\x13\x85\x8a=`\xd7\x04\xcd\x92\xfcs\x8eAp6\xab\xa3P\xe1\xc3\xad\xbcL\x9b\xd0\xe7\xab4\x87#}\x07\xb5~\xddW\x03\x9c\x1d\xb1\xd1\x98{t\x9d\x9a'
        b'Re\x90\xa0\xaa\xbe\xe7\xbf\x1a\x9d!\xbb]\xf3a3\xae[\xc3\xcdT\xc1\\i\r}\xc7\xee\xae\xff\xae1\xdf\xeb=\xc4\xd1\x82\x19\x897\x1d\x88\xca5(Do\xba\xd5y\xa0\x7f:\xc5\xe8~-\xc2\x89\xf7\xb1\x83\x9b'
        b'\xf31\xf4\xc8\xe4\x0b\xf1\xcf\xd5\x16\xaa\x14\xa6\x0b\xb8\xf2\x02;\xde\x90[R|g\xbf\x1b\xd2\xc9g\xca\xbbF\\(\xe7\x96\xdb3\xe5\xa6\xda\xe5\xce\x12\xe2\xa1\xc1\xe2\x9a4\xee\x9c\x954\xd2\xca\x158\x12\xc9\xfa\xdc\xdf\xd6'
        b'\x87\xd3kd\xf8s\x83 \xdbA\xd0\xff\x8fAt\xb1B\xdb\xc8\xad\x14!\x19\xf9I\xab[\xad\xdbQ=\x9c\x1e-\xec\x9c#\rI\xeaF4?\xed\xaa\xccV\x8f\xe6IBSv%\xfeW\x94h\x14\x865o\xb1D'
        b'\xf1G\xd6K1\xf5\x13\xb7\x89\x01\xb1\x7f\xfb\xbfO\x0bN\x1c\x89\xdeA\x8a\xec\xcai;\xff\x1a\xad\xe5\xb6\xb7]\x83C\xf0\xf8\xfa\xb4\xb6\xfd\xe9t5\x1c\x0cH\xa4\xd4\x90\x85P\xa3\xc2\xfa\xba\xd6\xedz4`\xb8)+'
        b'\xcb\xd6\xc0t\x92\xf2\x02\xe6\x1c\xcc6cZ\x8cm\xb5\xaekv\xdc\xdf\x95p%d\x80`\xad\xff\xfa\x1b\xa8T\x14\x93\xce ;\xcc\xc0^\xa2{"\xac\x07+\xe3J\x86^=\x84\x13\x93)\x1dw-(\xe6)\xe1\x14'
        b'6\xf8|\xb3W\xb5\xdc.b\xfee\x9e\xea\xb8\xa6/\xaa\x9f\x8a\xbb\x88\x9c\xf39\x8a\xeb\x01v)"f\x13F\xc3\xa2\xd1\x9c\x1c\x14\x10I#\xb3\xd6\xb4\x96V-6{b\x19da\x8f\xc7\xe0\xb1|\x0c\x05h8\xbc'
        b'\xc5p\x8e\x11D\\!\r\x00\xb2\xa2Q\xd0\xcb\xf4\xc8w>O\xa3q\xf3V\x0c+L\xf5\xearqE\xa8\xbf\xec\xc3j\xc4\x14\x04+\xc0\x90\xabq[ \x95\x15G\xe2^\x96\x06\xd1\xaa\xde\xb66\x8a):\xddA\xb2'
        b'W\xe5|\x8f%\xddX\xe7\xdc\xf0\x16\x04\x98\xcf\xfeP\xe8\xb4\x8cf\xce\x03\xfd\xbc\x15\xadS\x06\x14N\xd6\x95\xe1\x7f\xca{\x90\x8b\xe8)\x184\x1c7\xae\xf8|\xf5\xe7@AT\x8e\xf3\x03\xb5\xca\x83\xb8<9X\xbd\x91'
        b'\xf3S\xba`K$?[+\xcc\x90\xc3\xde\xd6\xac\x84RX\xd3*\x03\xf5\x1ePZ^S\nx\x95\x9du\x1d\xbc\x92\xb9\x96\xca\xf6\xd7td\xb3\xf9\xe2\x19\x1bA\xddw\xa9\x15\x88\x03\x18\xe5G\xf6N\x07\xac\xd5\x16\xa5'
        b'H5\xfd\x98V$\xe8\x83Q\xd3\xc1\x8el\x7f[\xae(\xf8P\x0c\x08\xd9q\xa5GE\xf5\xb8\xd7^\\\x97?\xf0Bz(.\x85\xfe\xd2\xb3Q\r3\x9b}\xcc\xae\xd0\xa5gNN\xd4Y\x81\xa1\xd8\xf8\xcew\x1cN'
        b'\\2k\x01\xa1\xab\x15\x93_A\x9cEq;o~\xf6\xe4\x1aG\x99\x1cw\xfe\xbf\x0e\xcbS\xae<\xb1S\xb4*.\x80\x01`c*>%*.KRrJ|n\xaf\xcc \x0b\x1f\x9b\x80\xd1\x02\x9a\x84Yf\x07'
        b'T`\x88\xfd\x1am\xba\xa6\xea.\x11\xe7.\xc8<\x9f\xb2b,Q\xb2!J\xf1x\xed\xd8^\x10\xa7\x9dX\xd4\x82\'u.OJ\xa2P\x1ej\xaaM\xbe\xf6\xf4R\xe5\x8e\xcc\xc5\x10<\x83?\xe0"\xb8\rr`i'
        b'\xf5j\xd0B\xaf\x98\x1c\xe5DRHrm\x86\xfc\xbe\x1d\xe5\x90=\xe6\x8c\xbeF\xc2c\x1a\xca1\xb5\x96>\xcc\xfd|\x1f\x15$\xb0?\xe9\xa4?\x1f\xc3\xd8YRE\xa2^\x15%\xc3\xe31\xdf\x95\x82Q\xee\x89\xee\xfe'
        b"\xb9\x15\x89\x050\x13\x0c>\x8fPZ\xf3'\xae\xeeW\xa4\xe8\x7fx\x8a\x8e\x1fU\xdc\x8d\xf4\xed\xf6H\xed\xa6S\xf4Mck\xb7\xbc;\xaa\x91%\x1e\xffC\x82\x04\xe4\xc8E}\x97\xdd\x0f#l\x03\x10\x8f\xc3\xfagE"
        b'j\xca\x95\x1b\x8d\xca\xb7h\xbe\xc9S\x04\xb0?,\x10\x18\x13\xa1K\x9d%\x02\xd0P\x12\xf8~(\x97Bc\x13\xd1\x1dl\x15%\x025\xea\xef\xdb\xd6\xea\xd6\xf8bH\xa5\x9d\x99\x9c\xcd\xf6\x86C\xf9FB\x96\xdd\xe0('
        b"`{\xbe/\xa3\xc1\x94_\xf5\xa5'\xbb)\xe4N\xe8\x19E\x8d\x8b\xdfL\x06j\xa8\x02O\xb6\xc7\xc4\xb4\x91!\xe8\x11\xb9yl\x8c\x9eD\x10\xc1\xbf\xc5$\x7f\xfe\xe4O\xf2\xd9iB^\xd1\xeeW \xa8h\xa9pe"
        b'\xe2\x08\xb0\x94\xb5\xc6\x1d\rsM3\x1c\xb7\xb3A\xaa\x03>no\x95\x82\x03\xfdZ\x1b\x01L\x0f\xab5J\x7f5\x0b\xba\xa0\xc6\xb1`\x00\x0eh\n\x99\xe9Z-\x1d^ 5\xd4\xbfcV\xeb\x8c\xb1\x03g\xacl\xdf'
        b"jY3\xe5\xe1\xab\xf1\xdc\n\x00b\xa9L\xfd\xc7\x06\x9a\xa5\xca\xc0T\xde\xd6\x195v\x01'}7,\xea\xaa\xd9\xa2\xa19\xfe\t5\x19\x10t\xbe\xce&\x1a&\xde\x1b.G2K\x87\xa3\xa1\x0c\x16\xcf\xbe\xc8L\xf0"
        b'\xd0g\xd0\xae\x16\x8c\x81L{\x90\x9f\xa2B\x9f[\x9aO\xdc\x92\x8aZ\xcd\xb6\xe9\x1a7\x99\xb7\xf5pf\xba\xe6\xc1\xf246S\x11\tl\x90M\xd3.\xe9\xfa\xac\x8d$\x0f%b4\xa17`\x07\xdc\xd3X\x1e\x12\xbe'
        b"\xe4{\r\rH\x05.\xd6?\x1f\x95\x9b\xf1\x0f\xd7l\x06\xbe\xe1w\x9c|\xefj\xbd\x10|\xc0F\xb7\xae'\xae\xb3\x86\xbe\xd2o\xeb\t#\x8c2c\xc0\x18\x82\xdd\x1a\xefn\x03\xd8\xf6\x9b\x84\x12\xd1\x18\xf6N\xfb_\x82"
        b"\xba\xe7\xb3\x81\xcc\x1f\xb4\x92\xd5\x9ec\x0e\x05+/&&\x8e\x18\t\xfd\x1fuod-!\xfe+1{\x0b\xe0K'>\xb3[F)f\xcd)\x8f\xf9]\xf9^\xa6\xd0\xc0>)\xd5\x88\x93\x18\xf4\x14\xa9\xcd\xc2\x8e\xde"
        b'\xf2\x85\x9b\xfb\xb0\xed\xeb\x1e\x03\xee\xcd\x9fy\x0b\xf8)\xe6[r\xed\xa4\xfe\x8bA\xb7\x9b\xa8_\xb3\xb3\xeb)\xde\xf2M\xda+\x9c7D\x1e\xf1\x8a\xd8\x0c\x80Q\xb7==\xa6\xa4\x97\x16\x1a\x95TA\x8fo\xdd\x9e\xf7\xfc'
        b'%\x84\xc5\xa5\x9c\xe2\x0e\xfa\xb9\xcf\xb2\xee4\x82\x1a\xaa<\xd3\xb0@\xa5M\xf6\xeb0\x18K\xa8\xf8\xccG\x14R\xa13\x03\xa1[\x19\xa4\x1b\xdd\x0f\x80<:[W\xc3\r\x95\xe8\xba\xca\x8e2\xd6d\xeb\xae\xb1\x8fBq'
        b"\xb1eD\xf9L\xcd9$\xdb\xc0\xef0\x8e\xfb\x00\x8cL\xb0\xe8\x90\x91\x1f\x9at\\\x86\x8e\xf1\xb8\x7f1\x14'\x85O\x99e\x02\x1f+&\x08\xf2k.4\xca\x87\x82\x90\xfd\xaa\xba\x9c\xfe\xb5\xdev\xfcw\x82\x9e\xa1\xad"
        b'\x992\xcen<\x90f\x15\x7fX\xeb\x94\xe27?\xe1)\x87\x87\x8e\x1a\xfb\x1e|\xd5\x88\xb3\xd0\xbd\xac\xe1\x00F\x17\xb2-\xb7\x98\xf8DH$\x0fF\xeeH~iu\xac@\x9e\x03\xc2)4\x9c\xb7\x03\xd4\xc3\xfd^\x17'
        b'\x07-\x9a!\x9e\xb9.\xd4B\xbf\x1c\xec\x1f\xf9\xd4S\x1c\x8bVr\x9b\x96\xa4\xe2\x0c\x89\x97\xff\xafrE\x042\x1f?B \x02\xf9hBD\x87\x08a:\xa8:\xce\xe6\x1d\x8bU\x15\x96\xf2`;\x91\tQ\xab\xe5\xd0'
        b'\x86\xb6\xe9\xdd?\xa7\xb5\xdbN\xd5\xc5\xa0FA\xcc\x1f%J\xe3q\xc8]\x84f\xa98\x7f\xaa\xf0\x0e\x1b8\xcbk\x15>\x1c\xecc\x84\x7fI2\x13\x02\xc6/w4;"\xcd\xea\xd8\x9aq\xb0e\xd2\x88\xd8#\x84\x1b'
        b'h\xfd\x0b\x9am%w\xb2o\xc4\x80\xa5\xefR\xdc\x85\xa0\x18\x94\xbc\xb0+\xb6\x0b\x15\xe3\xdf\xfdeRwa\x15\xf3\xb0\xf8\xa1\xeck\x16?K\x1a\xffZ\xe6\xb7#\x88\xdf\x99[\x1b\xeb\xfbr\xc9\xdf\xd9iy\x8c\xdb\xce'
        b'\xc4\xbf\x81\x981X2\x8bfx\xc5\x0b\x8f\xd0\xa5\xe8\x92\n\xbcCH\x1d\xb7Z\x9c\xb7\xfe\xc4\xddn\x9aF\xb9c\x1c\xe0j\xe8\xf571?\xae15Z\xa8\x9b\xbdli=\x87\xa0u1ngo\xc4\xdf\x0e\xe4\x12'
        b'\x9a\x10h\x06\x07\xb0\x0cu\xaa\x9bv5l\xf9\x19~\x1c\x11\x0cp\x95\xcc+\xfa\xf3\xdd8\xad"S\xffh\xf9\xda\x99\x95?S\xa5\xf2\x8e\xf2\x8d\xb1\x12\xb8\xe6\xd0\xbeLz\xc7S\x8f\xfb\x8d\xed\x16Z\xa1Y\xb8\xf2g'
        b'\xf59\xb2\xd3f\xd99n\xba?\xd0>\x94\xcc\x80\xf4\xac\xbfk%\x8b\n\x07(<L,\xc0f\x9c\xe1\x19\xa6\xebN\x1dl\rc\xe2rG\x10\xa26f\x80\xe7d \x1dCL1\xf2o\x0c,\x9e\xbc\xfe\xab\xb8\xb8'
        b'\xc7I\xe7$\x0c\x8d\x1b*\xb9?\xdb\x92V\xf9rB9\xcd\xc9\xcb\x0b\xc0q\xc4\xda\x89\xb6.\x05\x00\xe0\rx\x14^\xa2\xf2|\xa6\xa3\xfc\xf2\xa4\x87\xfb\x02\xb9\x07\xd0\xcd\xf4\xf8\xccg\x16E\x08\xcc\xd5?i\xf6*\xbd'
        b'\xc6\xd0\x91R\x0fV\xc5\x944\xf7+\xa8\x81\xbe\x0f\xb6\x92\x1d\x11W\xfew\xb9\xb7^\xa5\r\x94\x82,\xb2\xd0\x8aVA\t;\xe8\xc1\x8dE\xd1\x0b6\x18\x7f\xa9\x96\x86&a\x0e\xaa\xc5\x12t=V\x06sP\x991\xc8'
        b'\x0e,\xdc\xb91\xf9\x8ce<\x89f\x97\x08GqCg*\xc6\xf8>\x14}\x8e(\x91(N\x13\xa2!\x95Lr)\x83\x0cB\xc2Ug\x17Q`Z\xd6y\xf6*rQXE\xffj\xddU\xdf\xc2=\xcc\xcb5c'
        b'\xc4\x8f\x1aVfC?\xde({a\x96\x8eKP\\\xbbD\xdd%\xa0\xe5\x07\xcf\xcas\xfe\xbc\xf1_\xe5\xa1V4<V\x8e\xbd\xcc\x11\xcc"\xfb\x1cg\x05\xe0\x9f0\xdf\xc6u\xfc\x08M\xe7\x01\n\xf1\xc3\xaa\xa0(\xa1'
        b'\xeb\x88\x0c\xe3\x08~#&5z\xcd\xbcV_\xfc\xad\xcb\xe5Uw[\x18\x05\x04aM\xe1M\x18Fw\xf1\xf3rk\xb4&\xe0#\xee\xe2c\xcdl\x11\xea\x19\x1b\xff4Y\xe8\xa29;j\xd2\xb9\xfd\x91^\x07EA'
        b'%\x80\x01\\d3\x1d\x88\xc7\x13\x16q\x15\xe0W\xf5g\xbd\x16rpS\x08\xf35\xe7\x9a\xc7QT\xb5\x02\\\x8d\x1e\xd2\rDu:\x0f6\xa0\xa4\x0c\xf4u\xfdR\xa8\x00`\x9fu9g\xb7!k\x0b-P;#'
        b"\xc8p\x15W7/\xf4\xb8Aj\x0c-\xd8\xdf\xd1\xbd\xdbqrN\xda%\x81BZ#\x17ZEbF\xd8\xfa\x9c}Q\x0b\xca\xfcm\xd9\x96&\xce,\xf9\xff\x97\xa2*>\x95F\x0b\xcb'\xdf\x81\xb3L\xc9\xea&\xcd"
        b'\x95d\x11\xc9Kog?\x10\xd381\xa8\xbdGi}>\x97z\xdc\xdeb\x0f\x1a\x90X\xfc\x80\x8eL\x12\xaa\x80\xda\x97\xef!\xd31u\x80\xb7\xdb\xdf\x19g@G#\xa4\x9bh\xd9\xf7o\x8eH\x00Gu\x9a\xa3\xb4'
        b'\x90\xe2\xc0\xbben\xf5\x0e\x95|F\x1b\xfd\xaf\xc5!4\xd4R\xaf\xa6\x04V\x99+\xe18\xe1.\x91x\x1c\x8d\xff\x1a\xf8\x89\xc2(\xf3\x04\xb9\xc3\xef6.c$\x92\xce\xd0\xbb\xb3\xc4\xaf\xf5.\x90y\x88b\x8a5R'
        b"K\xc5Hdw\x9c#Ww\xb1T\xd8f\xf4\x8b\x16\x10\xd1\\\xe5\x8c\xdc\x0f\xbb\xb2\xccs|Q\x17\xfc\xb357y\xf5]\xc2\xdb\x87\xa1\xd8XR\x83\x05|\xe2\xc1\xf37x\xb7<\xd7f\x9f'\xdek\x81\xfb\xf2|"
        b"\x11x\x08\xe6\xe0\x0c2\x99\x06A\x9e\xb3A\\g\xfd\x8e{5\x0c\x85<t\x08#\xe0\x84\x0e\xa7\xf2G\xd9U\x1d'!\xe2\x1c\xff?#x\x96\xd9\xe4qm\x9b4\x00\xc5\xa5\xce\xa7\xa2\xb3\n\xee\xefU\xa6\xafD1"
        b'OV\xa6\xdf\xfc\xef\x97q\x1fb\xba\xa6\x8f\x0e(o\xe2?\x17\xbf\xdb\x07\x81\x98\xb8-x\x05\xdct\xcaG\x81\x89\x01\xb8^\x07\x9d\\\x85\xee\xa5y\xff\xcc\xf2\xd4\x82\x96,\x82\x9e\x95\xdbve\xfc\x12\xbecu{\x06'
        b"\xefI&\xe0E\xc7\xe2i\xcd\xafL\x16\xf8q\x99'\xbe{$\xda\xd3\\n\xac\xe8U\x1c8}\xb4\x05R\xad\xd8\x92\xfd<\\\xc0d\xe6:\xbc\xe2\xf2\xa6\x9c\xe9\xb9yS\xe1\xd7\xe3\x80\xd5\xde\xfd7B5QI4"
        b'\xdc\xab\xaa\xc55\xa1\x81W\n\xfcO}\xeb\xc5\x10y\x86\xd2\xa1\xf5\x0b\xa6\xfb\xf5\xa9|\x06\xd5\x83\xc0\'\xaf2\x91\x1e\xf7\x94L"\xebC\'\xe7\x90\x84\xbd6\xaeBos-m\x8a\x87\x90\xb6U\x84\x01\x0c\xae\xb8O'
        b'yEa\xf5z\\\xdb\x1e\x98\xa1\xa0\x19\xd3\xc3:\xc7\x88[\x0c$\x1d\x10\x82C\xf3#A{\xb0@\xa8e\xf9#(\xea\xee9j?\t=*\x1e\x01\x81\x05l\xa0G\xb5^\x1cR\xd1\xfc\xcaOx\x9f\x1d\x84`w'
        b'\x8b\x96\xe1wq>\x08\xa2\xe9)\x11\x89+Wg\x92\x02\xe7\x1d\x95o\xcc\x07,\xceyk\xae\xd1\x84\x80\xe5\x83\x04\xfb\xd2^\xa4&\xe2\x05?]Bz\x17\x12U[\x99Y\x0b(\xd6WU3\x90\xe6k\xe2\xc4\x01\x9c'
        b"\x9d)\xd20'-\x80\xe6'\xde3/\xf5\xd7@A\x0e\x82\xfe\x167\xa7\xb6\x1a\x18wO2\xaa$\x86m\x15\xe4uq\xfb\xcc\x05\\\x9a\x06\xd7R*\xc0\xfe9\x1f$\x8b\x90\xd4\xfd\xc5\x1c\xfb_\xbd4\xd6\nFX"
        b'\xb7\xd9g\xf4\xfb!n(l\xc3h\xc1\xd63\x8c\x85\t\xa5\xf4:\x9f\xfc\x1dnZ\xc6\xe16\xb1\xf1o\xb6\xd2\xda\x07\xd9\xcaH\xc4\xe5\x1f\xde\x11\xbeN\xab\xe5k\xfc\x98\xcc!^(\x07G>\x99\xe8\xf5ns\xce|'
        b'\x13\xaf\xa1\x7f!\x9c\xba\xef\xddV\xb8i\xe6\x08\xc0\xc73\xc1\x9a\xab\xa0\xbe*Zv\xb9\xd3\x9d\niF\xc9\tv\xa0\xed=Ga\xd0E\xb5\x1dC\xb0\x9d\x99G7\xfa\xff\x9bJa\xac\xb2\x0b\xee]:\xa5\xfa2\x17'
        b'I\xe7\x8a\x0c\xfc\x07\x95\xc7-S\x9f\x17\x19\x7f\x8a7\r.\x88\t\x1b\xc8\x1f\x1d\x1bC\x089\xf2I;\x1f\x17\xca~%\x839\x1e\xfc\xb9\xbep\xd8\x8a\xd2D\xb2\xfd\x01\xf7L\x0e\xe1\x99\xa9{\xa7Q\xad+\x81\xc7\xd3'
        b'\xd5pRd\xb1*\x1er\xedY!\x95\x9fR]\x01\xcdV\xa8\xf1\x91\xd3\xac\xc2\xd0\xdd\x08\x83n\xa7x\xd0\xce\xc8#\xc0a1=c\xad%\xc7\xb6\x06\xb7I\xcc\x89G\xeeq\xccNU~H\xb2~2\x1aGZD'
        b'\xf2k\xa7\xa3}\x88\x7f\x8b0[\x92\xebf\x98\xc5g\xc7\x19\x01\x9c\x9b\xd2\xd3J\xedn\x1d5\x99\xeew\x10|\xef\x95\xe7\xd3\xebio\xa3\xbe@\x87w\xf3\x93\x89\xf3-T\xe2\x0f\xa7QQ\x8f\x90*V\xa3\xee\xcc\xbb'
        b"\x1b\xcc\xafQ\xec\x96\xf5\xfffz\xe4Q\x8f\xd0\x98;\xa3\x0b\xb5\x1dt\xbeo\x7fVBO\xb9\xd6\xc4',\xfc{\x1d\x8b\xc3B\xa8\x02\\\xf0\x14?\x84\xa0\xa4D!\x8bb\xe9\x17\x00|W\xba\xe9\x9f\xa7\x0e\x06\xfb\x90"
        b'G\xaf\xcd\xe0\xf87\xbaw\x13\x9b\xd3\xc7g\xf7\xfew\x1f\xf8T\xf1\x8c9\x9e\x03\xe2\x1a\x90:"\x9a{pB\xa2\xde\xa4\xe3\xf38}\x08\x03\x12\x8d\x9d\xe3\x06z\xbca\xb8\xd1V\xc9l`\xb8\xb2\xd7\xceD\x99jB'
        b'\n\x8a\xd9g\xb3L\x91\xd8\xdb\xcaTS\x8f\xa4r!\x9d\x97\xc8\xf6\xba\xef\xc2\xd1\xc2\n%\xb0A l\x0f31{\xec+$z(\xd3\xc7\xafS\xc5\xd2.A\x1dn|\x8bGHj\xfa\xad\xb0t4\x15\x96\xa5;'
        b'\xab\x9c\x85 \x95M\x8a(\xdc\xa02\xe0\xf1\xbc\xad\xb0Fb"\xe4\xa5>\x8d\xd5\x16\x9c\n\x16\x8d\xe7f>\xb1]\x81\xe3.\x0b\xe1a9g\x99_\xaf`\x85\xfaW\xdcY\xfd\'-\xab\x0e5\xb5\xd8R\x95\xc8\xa5`'
        b'\x89\x02jpV$\xe4\x1adXcu\xeb\xb3\xf5o\x12\x16\xc7.s\xd5\xd6\x94m\x9e\xb4b/sW\xb6\xfe\x1b\xb6\x81?~\x9a\x0c\x17\x859\x12\xeaM\xc2\x06}\xa9xH&\xe4\xa3\xe7n\xcbuP\x8eH\n['
        b'\xa5\x15\x0eF\xa4A\xdc\xfaK\x87\x10\xb2\xed\x9c\xfd\x90\x1d\x17\x1b\x9a\x8bQ\xdef\x99\x84~\x152X(\xa4\xc2u\x1cpH\xb9\x05\x1a\x84\x8c\x03\xda\x93#\xd6\xcdhY\xd0\xd8:DgH\xdfX \x0e?\xbb n'
        b"\x91]\xda\x0c\x19\xd1s\xd4\xbd\xdc\x84PG\x10A\xaf\x15*g`+Q\xb3vy6\x04\xa6A\xbc~h\xfb\xe0\xeco\xe9\xbe\x8f\xbc\xaf\xfb\xbb\x9b%83\x86y\xb1!#\xf3'V\xdd\x1bYw\xb3\xc0\x99\xd1\xc6"
        b'\xe1y@\xe2<g,V\xcf)w\x18\xab=#\x10Fp\xe5|\x92\r\xd1\x89\x19\x9b\x8a\t\x86/\xe9\xa5\x1a\xb4\xa8\xa37E\xe2\xea\x94\xab~\xe7\x9bF\xfb\xca\x1ejMdm\xb0\xbe\x82\xec\xffq\xb3l\x03t\xf2'
        b'\xbcTZw\xf7x\xd4]\xe2\xea]B\x1a\xf5F\xc1$\xa1\xd4)7\x92\x17\xf8t\x1b\rc\xe1WTq#\x97e\x1c\x95:\xa6i\xf7\x84\xff1X5\xb4@\xfd\x99k\x0f\xf7\x9a2\x80\x8f\xac\xed\x84\xd6Y&\x88'
        b'\xe0\xf1\xe0{]*{I\x99G\xf1q\xd4\r\xcd\n\x9f\x08\xf1\xe6\xe9\x0b2\xe8\x91mf\xba\xe0\xce\r\xb1\xc2K\xd4s\x16Gh>\x1a\x83J\xf5\xff\xbbqm|\x9erw\xf60H\xfe\x95\xed\x05\x1f\xe9\x99\xf0\x16'
        b"\x88\x18\x91\xb2\x0b\xef=n\xa6 \xffO\n\xf7k\xa8&\xe9\xfbH\xcb\x95\xc9\xdeV\x889\x1d\r,k\xbd\xa3'\x1e\x8c?\x10\xa0Gb\xfb\x934J$\xd3\x98\x0fp1\xdc\x92\xb9e\x07\x90o\x17\x96\xda\xcd\xf0\x08"
        b"\xb0\xe1\xc8b\x04pPb\x1fAK\xd5\xf2\x0c\xc7\xe2k\x17\x00\xa1[\tu\xf1,[\xac':Y6@\xe0cO(\xf9\x85\xc8&\xde;\xd0\x00<\x86O\x8b\x9c\x07\xe7u\xceQ\x9c\xea\xe2\x82<\x15\x99\xd2\x02\n"
        b"B\xa7?\xb0\x89\xf9d\xee'E\xd9\xe3S\x1f>\x11;\xde\x02\xadyG\xeb@\xdb\xa3\x1e\xa5\xe3\x9dE\xec_\x94\x9d*\xc7\xd4\xc2\xce\x05p\x9d\xfc\xa5\x9f\xef&|\x10\x04\xa0\x15\x92a\x98\x14\xc9\xce\x93rC\xb0<"
        b'\xf4\x81\xe76\x0f\xe3>d~\x1e--\x90\xe8:\xedO\x87\xf4\xc5\x88\xc0>|\xda\xcf\xd2\xc7\xab\xc8!o~3\\\x85o\xbb\xe8\x11\x04\x02I\xef\xeb\xa4H"\x08!h\xdc\x9d\x96F\xae[\x11\xd3P\xc2%M\x02'
        b"\x0c\xd2Q\xbft\xa4\x0f\x11\x93\xd9\xe6\xd3-\xd8\xf4\x84s\xc3\xf2\xf5\xe8\x86!:~\x82\xd3'(f)\x85q\xc9\x17\xd1\x0b\xad\x0b&\x9c\xe7\xda\x06\xd59G\xbc\xfc\xfb\xe8)\x0f'\xaf\xbf\x1fj\x8d\x04`1\x10\xf0"
        b'\xb3\x11\xb1k\xa4\x10\x03\xafR\xa4\x1f\xf4B\x92\x95R\xdc\xfbrc\x14\xd9\xa0\xc2L\xe7\x02\xca\xcf\xdd\xf5\xd2,a\xce7\xe6\x87\xa9\xfaEqu\x87L\xa2L\xddHy\xe4h-\xad5\x08zj\x1a}m\x83B\xcb'
        b'<\x0f\xb4\xa4(\xd0U\xbb}\xcd\x89\x88"l\x0e\x8eo\xfc\x8f\xe8U\xf8U\xbbf\xc6G\x0b\xe0\x90j\x8e\x12a\xe9j\xe8\xd3V\x13\x08\xffdt\xd0$\xf6\xa8\xbf\x1a[\x18=\xc8\xc4\xfb\x08\xbe\x85\xc1\x9b7]\x8b'
        b'\xde\xd6-\xccRY#\x05@\xf3\xda\xb1K\xd6\r\xb5-\xc2f\x89\x16\x14\t\xc2,\xd8\x8f\x8b\xc0\xf5\xdcM\xc1S\xbee\x00\x9f\xab\x89\x9e\xc7j\xf3Q\xf4\xa4\xbf\xb0\xb7j\xc8X\xe2)\x97\xe87\x9a\x98\xff1\x9c7'
        b"\xcb\xbe\xe1\xc4=\xe9\xe6\xae\xef\xcc\xfe\xacp\xfa-%r8\x8ex\x89\xc5\x04{e\xb73\xbfz\xe5\x86t0\xa2Fa'\xa5,%\\\xfd\x92)BU\xff\x8bW\x96\x89\xc9\xc3\xb6\x81\xc8\x07\xc0H\x83\xa7T\xb9f"
        b'\x7f]\x18d%\x1d>\xf2\x95s\xd8\x8a\x7fS\x05\xd9\x15\\ql\xe9\x02\x94F\xd3\x94NerG\xe5\xac.\x9a\xd1\x98\xee\xa0\xdc\xbf2\x95C3j\xfeyLF91\x1d\x0bze\x88n\xc7ID\xf5M\xfc\xb5'
        b'\x97\x01\xb9_=\xa7\x05\x95x\xebuE#\x82\x93\x0e>H\xfaI\x1d\t\xfemyJ\x8c\x86\x97\xee\x9c\xdc\xba6\xac\xd3\xa9G<\x1b\x1e}Q\x15\x92L\xa9\xbc\x1b\xc4x\xca\xdc7\xb4Z\xf6\xbd\xa2\x88\x06\xb4\x1c:'
        b'\x9d;?E\xc6\x13\xa23\x8fG\xd4D\x06\n\xae\xc4[\xf4Xb\xfb\x91\xbcR\x8b\x8e\xf4\xac\x1bu\xf1l\xf6\xaf\xe9S\x06\x87\x11\x92\xee\xa0R8w\xa50B\xa7P\x89\xb0C\xe8m\xad!\x83\xe0\xb5\xcdW\xb2\xf9'
        b'(\xc1\x9f\x1fu\x1d\x11\xa6\xa8h\xbe\x10wu\x11\xd6\x82!\xa4\xf1\xcaD\xf4\x03\x06#\xec3Zr\xc1k~\xcd\xdf.\xb0;\xcf\xef\xbb\xc6t\x90aW[\xb6\xd9\xe1\xbd\xc5\x956\x1e\xd2\xf7\xacVp&I\xc1\xea'
        b'\xed\x7f-} C\x1f\r\xa9{\xdc\x07x\xd8\xae\xa2\xfc\xb9\xe9\xaf\xce7\x85\xc9.\t\xf2\xe7@\x1c\x15-.\xe0\xb9\xae\xd2\x9d\x1b\x1a\xabw\x9bz\x07Wu\x9f\x0ccv\xc9p^\x94\x9a)\xe6\xb7\rx0\xabW'
        b'\x19^\xfcm\xd4\xbb\xe7\x8d\x15\x95b\xb9\xfe<[\xbe\xac~\x03\xfbH\x0c\x01\x8b\xbc\x1a]&\xc3\x07\x1bE\xbf\x9a\x12\xba\xb4\xf2X\xb86\xcf\xe3\x8f=\x9f\x90\x87\x91\x89=\x0c\x83\xff\xcbf\xb4\xde<g=\x88I\xe5'
        b'{\t\tO\x1f\x94m\x03\xfd=@\x08\xf6y\xab\x18\xe5\x9a\xe2A\x872\xe5\xa5\xe6\xe9=\xaf^\x8c\xc7\x10\xd30\xae\x8c!\x06\xd9Nka\x1b\x03(\x11?\xae\x05\xf52yQ\xcdb\xfd\x16y\xd1m}\x1f1\x81'
        b'\r\x96\x1eR\xc2(:\x00\x08B\xf2\n\x8a\xba\xc2\xbf+\x049\x0c\xd5\x0c\x86Nav0i\xad\xf0*N\xd25\x89\xc4rPhg\xb7\xa7^\xd5\x95S\xf6s\x02O\xeb\xac\xa36\xda\x90\tJO\x03\xfa\xcf\xfd}'
        b'\xa6g\xe6\xb8S\x19\xa6<\xac\xf0n\xd2i/\xf5KS\x16?\xfdZ\x83\x88\x18\xe4\x15\xa5\x14\x18T\xf2Y!\xfd7Y\xf4;\xcb\xe1GH)0\x00\x96\x05\xa3\x16Z\x8a\xac\x14\xea\xf5\xea\xe1t\xe1\x0fF\x01\xfb\x97'
        b'\xe3V\xfc\r\x16\xa5\xc8\x81\x10\xafa\xe49\xbb\xf5\xe4\xe9\xf7\x82#vL\xbd3\xa5\x10Yy\xc3_\x8a3\x11\x15R\x06\xbf5\x05\xb9b)^W\x1e\x86\xcfT\x9eC\xaa\xec\xe2,\xb2\x9eYN5\xd3\xdb\x11\xb4\x8a'
        b"\xb6\r\x8b\xdd:\x80\xd8d\xb4\xad\xf7\xe5>=`\xb0\xfbe\x01\x90\xdc@\x91\xf0\xb4\xe2\xf0c\x04\xe6$\xec\xb0|\xd2\x8dj#\xf2\xe9zV&\xf0\xa9\xd8\xe0\x8b!\x0f\x98\xc4\xb1\x1e/\xd05\xe1'\x89\xc2\xc8\xe7\xd6"
        b'B\xce\xb2;+r4/@\xc7\xb7\xc9\x153\x8f\x12\xf9\x02\r\x1d\xf7\xee\xc4+\x15\x1e\x9b\xb0\xdbk\x0f\xd5&\xb1\x83\xe2\xa6_h\xbd\xaa`\xaa\x92\x1b\xf0\xd5b!v\x05!~\x1dU?\xd3M\xf4\xa8n\xda\x98\x7f'
        b'\xd7\x91\xa5\xe2$\x0e\xc9\x92\x02\xd6\x13a\xfaH\x8df\x99q\xea\x89\xcd\xf9;\xcf\xb5\xc6U\xb3\x16\x82\xc6\xce:\xbc\x0b\x07\xf0s\x8c\x8bU\xc5\t0sf\x9b\x11\t\xe8\xde\xceT\x8f\xe3\xeaX#f\xa7\x00k\x18\x1f'
        b'\xb4\xc0\x1d#\x07\xd6\x18 \xee2\x06\x83\xbe\x9c\x87\xa6\x82\x1d{\x17\x88\x0b\x11i\x9e\xa7\xff\xab(}z\xe3\x1d\x84\x9aN,\xbb\xc6\x99\xf86\x07.\xbc}6\x9a\xce\xb86\xa2_\x8e\xd4\x8f]\xf6h\xf2\xf1\xafz\xe3'
        b'\xbd\xbc\xaa\xaa,\xf6\x05\xff\xe6\xfbwS\xfe\xfaL?c\xcd\x0bH`\r\tz\xb8\xb4]\x89\x87\xee\xdf\x14\x00TX9!f\xf9\x8dM\xe7\xfb\xb8\xa7\xac\x9a\x99-\x8a\xb5\xc9\x0f\xa2\xce\xea\x8bw;\x9e\xc4\xcdz\xac'
        b'\x9bTe_\xef\xed\x0e\xee:+\xccmDNk\xf0v?T\xacEWd\xd2\xca\x13\xd9\xfb\xd1WF\x81w0\'\xb3\xd7"]\xadH\x05\x1cI`\xc1\xae\xce\x7fE>/E\xe0\xcf\x85\xa2\x12\x8c\x0b\xe9\x0b\xaa\xe9'
        b'3\x99\x19/\xec\xe0y\xca["\xea9m\xbf\xa6\xe1\xb0\xe6\xe3\x98+\x07 \t-\xe8\xd3\x0c\xebc\xc8p\x9c\xfb\xb2\xf2\x7fp\x03\xd4\xdbL\xee\\\xda\x8a\\\xf2\xc2O\xf9g\x8d\t\xa2b{\x07[5\x1f-\xafo'
        b'?\x91\xb6\x13\xb3\xeeRh\x8c`\xa2\x81Yu1\xceF\x01\xc9G\x11\x03\x8cI|Zx6\x9bP\xce\x03\xdeY\xf9^\xf6\xf7\x8c\xb1S\x84T[\xe15\xcd\xe4\x10\x84\xa2Dl\x8e\xc9\xb9\xc3\xd5\xcf\xd9tW\xac\xc0'
        b'\xc8\x00\x1ea0\x0f\x87\xe2?\xa2\xb2\x02\x0f\x8d\xe8\xb0St\xed?M:\x89\xafk\xda\xe7)\xcc\x196\x17MhfR\xff4r\xd1\xc3\xe0?\x85\xe5\x8c\x1bF\xb8\x84\nD{\xdf#c\xc3\xb6\x80r[\x01\x90\xac'
        b'~\xa8dH\xa2\x9dv\x88\xf5\x1b\xf4\xa1\xa1^\xe1\xa6\x1dm2\x19\xc3\x9b3k\xa4\x96(\xf1\xf2v\xaf_2\x81\x0b\xc4\x19\xde\xd5\xb6\xcc{\xf3\x8d\x82\x8d\xdf\xe8t\xc7\x92)\xe0gj\xf0D\x84(8\xc4\xab&F'
        b'{P\x04\x85\xd8\xc3\xba~\xb1Ro!\xcf\xe3\xac\xab\x7f\x8d\xcf\xbe\xd6\xce\xc4]@>PN)\xca\x90@\x05+\x8db\xd0\xa3L\xad\xcf\xefo\x99^9\xaf\x94\xe6\x08\x8c\xfd\xdf\x1560\x1c\xd2\xf3Vm\xb34\x0b'
        b'M\x00\xbb\x1fU\xd2\x0e\x06AC\x17.\xf1f?^\x96\xd97\xfbhzh\x8b\xf6/,p\x8d\x0e?`\xb9\x18\x86\xa4\xe0\xc6[\x84\xd1Ug\xea\xb4\x80@w\xfb\x814("\xc6@"C\x12\x1a#\xc1\x81\xad\xab'
        b'\x03\x0b\xef\x15=\xb0\x0eV\xaeY?\x9e+\xfb\xb9\x87c\xbf\x00\x98o\xcc06k\xf9\x8c\xee\x16\x12\x84\xd7%\xe8\x08\x1a\x85\xf7\xa0l\xf6\x84[\xa5^,\xac\xcb`s\xa2\xb9\xe4\x8dG\x9c\x8e\x80M:\xed \x8e4'
        b')\xb4\xd79X\xbe\x8d\xbf\xf0X\x05pt\x12g\xf4)J\xad\x98\x03\xb4\x0c\x98F,\xf3\xc4rs\xda9\xad\xaeg2\xa1!\xfe\x0b\xf3\xeaxT\xc2\xce\xef\r\xdb\x80\x99\xd2\xa32\xeaWm\x08\x1ef\x13\xbd\xb0\xe7'
        b'H\x85\xbc\x89%\x85h\xf8\xd7\xdb\xad*MHBV\x00\xccz\x7f\xc7\xc9N\x91\xe3\x15\xfb\x00\x12\xe8xk\x087<\xcc\x9ex9\xda!\xa6\x8b2\xcc\xa6\xb28_\xa5\xcf\xf7\xb6\n\xcf\x9c\xf6\xb7\xdf\xff\xa2z\xff\x03'
        b'\x81\xf7\x9a\xd6\xa7Y\xc5\x0e\x97\xae\xdcj\xb3W\xce\xa8e\x91\xe5}N\x96\xaei\x1e\xa4]\x807\xab,\xcfV-(6\xbfL!G\xac,QI\x92-`\x14K\x18dw\x84\x1a\xbb{Zx\xe5\xa7}\xd3\xbf\x07'
        b'>\xe9)\x06Z4]\xd0\xef-D\xc83\xea\xd9O]\x06\x8f\x16\xde\xe4F\xeaFP\xd7\xfeU\x07\x1e\xce\x92\x89<\x94t%\x9f\x02\xa3P_\x96Yh\xbeH\xca\xe3\x82\xa5)x8\xdc\xf4\x9aLZi\xe24\xd1'
        b'\xc4\xd6\x8d\r\xa4&\xb2\xe8k\xf4\xa0B]t\xb8\xb8\x05>\x8c\xd2}\xa3\x8e\xba\xd9`\x96\x83-I\xa8H\xfd\xc91)9\x80\xb44cg\xc5\xf2A,c\xfb\x18\x81\x9c\xe2\xcc\xee\tcE\xe2<\x1d\xc9\xd4d\x83'
        b'f\xad\x1b\x1c\x9ae\x10\xd4e\x94;\xc1w\x93\x16\xe4%\\\xe2\xcb\xd6\xb1\xcaEX\x13\xd9\xb7Y2\xe0\x83\xd1\x8d`\x9c\xda\xf1\x81\x18\x1e\x04\xf8\x88\x1a=\x0cPPD w\xb1\xc2e\xf5\xb7\xbc\xd9Svsw\xd6'
        b'\xff\xeb\xa8\xda%\x0b\x98\x9at)\xc6$\xe3\xfb^\x05\xa2i\x10d/K\xd9\xcc\x03\xb8\x0bHk\x9e\xe0)\xc8\xa2@JkE\xde)\xc4\xa6\xec\xb33\x12\xc7\xb9\xb0\x95\x8c\xf7\xef\xfc\x8eN^\xac\x87\xd3zW\x82\xf2'
        b'\xae\x99fu\xaa+\xc2f\xecn,\xb6\xb0\xa1Zn\x90F\x16\xd7\x109\xf3\xea\xc4\xd1K\x19\xf47\x19\x80/)4\x1f\x12\xf4\x12\xe8\xec)\n\x85\xdf5"\xd0V\xd1\xfd\x15\xb3+\x18-\xe05x\xe9^-\xff\x82'
        b'\x97\xef\xd1\x9b\xbc\xfa\xd1\x1cI\xb2\xe13\x1ew;\xb4\xfa\x91+\xcb\xcdW\x18\x85\xb3J\xa5\xae\x02\x1b*\xff\xb84J\xdey\x1c\x14\xfc\xa2\xb4\x96\x88\x89\xc8\x1a\xcf\xc4_\x96E\x0c3[\xcf]\x0b\xcb\x14,.\x06\xeb'
        b'?\xdf\xd4\xc5\x12H\xc5!\x13\xb8\x0bv-\xbc\x1b\xb8A3\xb8\xc0\xb2\x81(\xe3\x06\xa9-\xcc\x85\xc8\xea\xc4\xb98X\x93 I\x94W\x9bT\xae\x04\xb5}\xa72\xcct\xfd\x94v\xf5E\xb7\xc1\xe7T\x80yc-!'
        b'\x0e%\xb0c\xc6\xdd\xa9\x97t\x0em\xe4%\x1c\xca\x885\xbc\xef\xc3Bb\x82\x8f9\xdd\xd3\xd8\xb6|\xe5\xd0-\xa0\r\x9e2@`\xcf\xed\xe2\xec(!\x13\x91\xd3\x87\xec\x87\xe0\xdd\xfch-\xc7\xd0\xa6\xabd\x8dn\xb8'
        b'\x8a\x14M\\\x9d\x1e\x87\x08n\x98 \xaa\x04Zh\xe2\x07\x84{\xb9\x9a0z\xd6S\xd6\x9f\xd5\xb8\xdce|\x99\xc3\x1c}G2s\xf0\x01\x10@\xaf\xdfLK\x87B\xf4u *\xaa\xd8\xd5/\x1b\xcc]T\\\xaf\xe1'
        b'W\xa0\xcf1\xafK\x1b\xfd\x97\xad\x0f\xbafQN\xef7\xdc\xb0V\xc4\xc8M\xfd\xcb\xf6\xa2s<q\xeb1qvG<\xef\xf0\xfb\x02\xddtZ:Q&\x98"\x06\xc5\x19^\xdc]\x81X\xe1\x94-\x886\x9e\xccX'
        b'c\xb1/\xec\x8b\xed\xf1S\xe7\x82\xd7\xe8\x92\xcf\x07\x12\n\xe0v\xe9\xfaO\x87s\x90\x05v\x99\xbd\xa4u\xa2}\xd6uP\x82U\xd8\xb7\xad5\xae\xcc@\x82\xb2<\xf5D\x1bME]\xad\xcf\x19W\xbc\xf4\xff\xda)\x1c'
        b"\xe2'\xd5\xcbVv\x0b\x86\x95\xd9,\xa4\x06\x1a\xef\x11\x8e\x88\x9d\x14\x90\xf9\x84\xa1\x06O\xbb\xf8\xfc(\xde\xf4\xa8\xc1\xd4>N\x1a\x0eIZ\x91<\xd4\x18\xd3R\xa5xY\xef\xc4\xf0\x01\x0f?\xa6e_\xe9\xads\xd1I"
        b'w\xd6\xde\xe5\xb3m\xdc\xac\xe70\xd9\xdf\xeb\xba\xb95\x10\x13\x97\xce5\x8dV-\x1c\xe9\xb1\xa2#\x13\xfa \x12\x1c\xed\x1e\xa9\xdd\x18\x98\x9eDBE\xebq1\x1d\xf1\xc4\xea\xba\xef\x0e\xb8XZ\xe1\xc1,~\xa5\xd5E'
        b"$\xc1\xdf\xa8\x98W{\xafU-q\x95\xe5\xc2\xdb\xbd\xff\xa6Vk\x827\nO\x0ek\xc4\xb3\x87\x8b\x9b\x16\xca\xf8\xbdw~'\x9e\xb5sI\x0c\x13\xb0\xda\xff\x07))\xd1Q\x00\x90\x8d9\x89)k\x12\xf5\xf3\xb97"
        b'#+K\xbe4\x92\xff\x9e\x1b\xad\xafQ\x07\xff\xca\x13A\xa06\x93U\t[\xba\n\xceF\xb9\xd8\xaa"\x1a\x12\xfa\x15\xc6%\x05&0\xc2\xf0\x95P!\x00XV\xd4\xa6\x13\xe8$X\x80\x8a\xef:J\xfa\xa5\x1dYG'
        b'\x0f^b\xdc\x0f\xbd\xbb1<\xdb\x1d/,%t\xa2J\xed\xda\xb9\xa5\xa5\xa8\xdd\x02\xfc\x10\xe4\xd7\xe5\xb4kO\x00\xbf\x1e\xb3\xca]6y\x15=\x8c\x0f\xcf\x15\x8d\xeb\x10\xd3\x8f}x\xe0\xe8R\xda\xa8q\x8eN\x1b\xf0'
        b'\xdc\x03\x0f\x0b\x18\x14.\xa1\xb2\xef\xab7\xd0\x88\xfc\x84\x82\x16\xf7\xc6b4\n\xa1\nZY\x84\x08;\xd5\xac\nMl \xdc\xce\x16\xcb\x0c\xd2\x96\xbb\x82\xb5x\xcbpW\xbc\xe9\xc4k\xa7\r\xe8\x84\xf4W4\x1dB\xd5'
        b"\xbd7\x1e\xfc\xa8\xb9Y\x95\xa6\xbeV\xfb\x84\xae'\xb9\x85\xff|\xad\xb4\x03\xff@Mb\xca\xb8\x02\xde\xa7N\xf5>\xe9\x11\x11\x1d8*\x9e\x16E\x08K\xeb\x8f\xc4&\xab\xcf\xf1\xcd512\xc4\xb5\x8b\xdd\xd4+gS"
        b"\xfe\xe7\xd0\x08yx\xb2\x06\x81;\xa1\x8f\x929\x93=\xc6\xe6M\x8f\xac\x8es\xc8{{\x93\xbc\x1bSF\x95\xb2_\xd8\xa1\xcdK0\xa2\xe3\xf5R\x07\x06\xbbY\xd8'\\\xb2,\xaf\xcco%k\x8cl\xd3\x08@\xa1-"
        b'\xb7F\xe11#%^\xb2\x8fI\x19\xe9\xc9P\x02\xbe\xa5\x8cq\x98+pc\x85R\x12\x88.\x00Ha\n\xb0\xfbp\t[\x94Sp\x00\x9c\xe0oy\xbapx\x9c7\xd9\xa4\xac~\x1dE\x1a\x96m\x7f\xa6\xed\t\x95'
        b"'\xd4\xdf\x9d\xe3C\xbd\xc7\xbc\x01\xb5\xce\xeb\xcaM\xf4:\xcd\x1e\x03\xb5t\xb7\r\x9exy\x8exgDw'\x08+v\x03B}\xecItRx\xc5\xcd4\xe8\xd1\xb6\x0c\xe8\xc8e\xf8\xd2`\xfd\xbb\xc2n\x0b\x15\x96"
        b'\xfe\xe3:\xf9\xc4w\xae\x98!\x06\x95J\xd6C\xc8\xe8~\xf9o\xbb\xdc\tK\xcd\x89\x08T\xf2\'&\xa9E\xe2\x04\xd4\x86m-\x94\xe3\xcaxbm1T\x86w\xd1\xf3\x92\xdd\xccR1\x90"\xe9\x01\x00\x00\x00N)'
        b'\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x15<f'
        b'rozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
