
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']


def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    pass


class SWIFTParserError:
    """
    SWIFT parser returned an error.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadedsd.\x00\x00PYARMOR\x00\x00\x03\x08\x00U\r\r'
        b'\n\t0\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00$.\x00\x00\x00\x00\x00\x00\xcd\xe7\x15\xa21\xd0\xdf\xc3\x17\x18c#(\x8e\x9b\x1d\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2o>\x8e\xc4\xaa=\xba\xc7a\x07\x86\x1flL$E\xb9W\xe8/\xe4\xb1u\xd0%\xd30\xd2\xda\xa11\x1e\x16\x9c\xf7(,\xc2\x8f\x15\x02_I\xf5G/\x08K\xa8\x95\x9f\xbds'
        b'gZ\xf7 7eTS\x91\xcd\xeb\xa1\xe46`\xb3\xcb\xe7\xd0\xb0\xfaZ\x0f\xcf\xd2\x91\x06\x83\x9e\xb8|s</\xa0\xe2\x9e\xb2\xde\x02\x9e\x98;\x9f\xef\x82\xb9\xfaIj:\n0S\xe3\xf0\xdc#V9\xf3\x92\xf6P'
        b"8\xd5\xb2\xeb\xab\x85Z\x0f\xc3\xf8\xcc\x93\x13\xe6*\x8fQ\x0c\xad\xc4u\x17f\xca.\xac\x10\xa3J;\x81d\x0eQR\xa2)\xa8\xdee?\xb3\xfbA\\\xca\x88C\xca\xad\xb9{'\x138\xbe\x12G\xa4\x9b\xfa\x96\x00\x90"
        b'j\xb0\x94E\x97\x1efrfR\xbc^\xa9\xb9h\x1f\xbaV/\xbfg63\xf4\xa2\x03\x01C\xa0\x8a\xbd\xc8\x9a@\xa1\x84-x\xd8\xadM\x99\x90\xdaX\x10\x07\xb6\xab\xc9~\xf9t\xc3\xfc/\xd8\x05\x11\xc0\xcf\xea\x80\xfe'
        b"\xe6\xe7n\x1b9NF*\xfeJ\xd5{?\xa6\xc3F)Z\x87\x05K\xe2\x8do\x15\xe1\xabs\x91x?\xdf\xe6U\x06\xe0,\xa5 *\xe2\x1a\xe8D\xf9sU\x96?8\x04\x83\x12p\xb8\x19\x95'\xf6}\x1c`H\xdf"
        b'\x18\xe6o\x01\t<]\x05;\x0c\xfa`\xdad\xeep\x96\xe0\x9c\xa40\xd9\xfd\xc8\x05\xe1j\x11\xd4^\x95\x9dQ\xe4W\xed\x00\xb9\xfdd\xea\x8d\xa2f)\xc8\xe0\xd2\xd0\xac"\x1f\x04\xdctp\xbe\x00\x9f3F\xc9Y\xf0'
        b'\x03\x95G}|\xd3\x97\xff=\xbdGqV\x86x\x07\xefl\n\xac]\x89\x1a\x97\tD\xd2\x1e\x82\xb1w\xb1\x9d\xa3\xbc\x18\xf8\xff\x18>\xe8\xcfO\xeb\xa4\xc6\xc0\xc0\xc3:S\xc6\xe7\xbd\x02W\xa0\xc3\x11\x1b\xf1\x16\xfe\x07'
        b's,\x7f\x9e\xd4\x94\xdfdw\xf3\xd3\x18l`u^\xe4\x06B\x1c\x86v\t\x19\xd4-\x04|^"8qh0L0O\xaa\x04\xd84\x8e`\xfa>N\x0f)\x8b\x11\xc2\xd3\xcbD\x12\x12\xccZ\x0e\xdaE\x0b\xe9\x99'
        b'\x17\x04C\xe4\x02l~TH\rF[L\x15R.\xec\xa0\xd7\xe7\x81\x15\x1a\xe8}\n\xa2\x16\xb3\xd9e\x9b}\x9fv\x12\xa2\x86\xdb\x96IEe\x9d7\x08\xa2x\x8c\xfd`s\xdc\x00\xb9\\ \xc5\xb6_\x14\xa3Q\xc2'
        b"\xa7@7@\x04\xb9?\x01\x029)\x9b\xcb\xeda\x00B\x89\x1e\x86\xa4@;\xf6\xb9\x9c\xc0l\xa2?\xd8\x19\xa2\xa0AIH\xc7f\x11\xaa\x86\x8c\xeb\xcdO\x00\xca\xc0J\x89-\xe7'v$o\xf06_\xc4u.\xd4"
        b'\x87(\xc9\xe4\x8a6\x1eB\xfe<\xd7\x80\xce\xd1k%G\xc0"\xd121\xcc\x9eq\xab&\xfb\xcegB\xbd$\x1e\xd2\xc0`,\x7f\xee\x17\xd2\xbf\xd9n\x0c\xccL\xa7\xdb\n}"\xfc\x82%\xb9w\xae \xd7^\xbay'
        b'*\xb8\xd8igF$\x9e\xdf\x98\x01k\xde\xa1\x97\x7f\xeb\xe0\x16\x99\x1e~{h\x02\x0b\xfd\t\xc0\x19-\xfe\xbcsz/\x9b\xbd\xa9\x99j\xd0\xe6j\x90\x9d\xcb\xfa\x90\xc3R\x8f\xf6G3_\x0c\xb9\xa9\x1b\xa7\xd1B\xd1'
        b'V}\nD\xbf3\xf3z\x1c\xe0\xa11\xee("\xc1=\x157\xb1\xb1\xc1\xdfu\xd2+\'\xd9\x8c\xc9\xeb\xf4\x8d\xca\xba\xcf\x80\xdak\x11\xba\x84\xc3\x0f\xe2\xc2\xf7pa\xa8\x85\x16\x11A\x86\x08\xe5\x0fYJ#\x02\xe7D'
        b'R:\xe2\xe7)\xd9\x9aU\xa3bu\xdc>{\xa52#k\x81\x0f\xde\xd7\x89\x08\xd4\x1b\x9e\xa8\x027<\xa2$8\x9a(\xe0\x91\x92\xd8WT\xa2\xde#\x9eM\x1c"$\xa5\x11\xc3\xfb\xf3G\xff&r\x81\xa5^L\x1b'
        b'\x91_T\t\xce`\xd8e\xe2\x08?\tD\x96\xae\xa7\xc7\xaa\n{\x8f:\xdd\x11\x01A\xe2\xe1\xb1\x9d\x7f\xe6\xadD\xae\x19VU_C\x9b\xf37\xed\xcc\xe4\xea\xcb\xa1\x17\xbc\xd0\x89\x8b3=\xe0\x14\xf4\xc4g\x7ff%'
        b'H\x9a\xe7\xe2\xa4\xb7\xca\xd0t\xe9\x1d/\xc2\x07\xa9&\xa2\x11\xdfx6\x9e7C\xe2R\xb2S\xaf>]!\xe8\xa1rM\xf2\x00\xe8y2\xa9{\x18R\xe5k\xdfa\x10\xcb\xfd\xbaN\xee+\xa9A\xdfv\xb0J\n\x80'
        b'\xaeG%\xf7\xa1\xc7{\xd0\xa1(G\x1fP\r\xf0Jr\x8d\xea8"\xb7_cP^\xcb\xe1\xb1\x17&q\x1d\xbfl\x146^\x04\xad\xb6\xd6~/M;2\r\x80\xe6\xc1\t\xfc\xbe\'?\'\xe9\x1b\x17\x06E1\xcd'
        b'\x9e\xcfQJ\n\x9f\xd1\xban\xce\x1b\xe4\xf3\xafw\x99\xa8\xa5\xac\x8a\x07\xfe\xee\xc8\x17\xf9\xc1\x0c\x8b\x9a\x06I!\xc4\xbf\x913\x95\x171\xcc?\xd0\xf3\xa1#c\x00\x9a\xbbA\x8b~\xdc\xe9\x0f\x95O(\xbb\xe7X\x99p'
        b'\x12\x00\x1b\xd4\x9d\x8f\xd4Z{\x1c\xc7\xed\xb9\x9c\xb7\xd0\xf1\x01U\xd1\xaeP\xdb\x0eGCe\x17\xafHp\xad8\xbc9h\x0ck\xeb\x1d\x9a\xe0\x1cw\xc2%92_Y\\~\xd2\x18\x13g\xe2\x96\xc4u\x95*G:'
        b'\x01\xfb\xab*\x96~\x14)\x06{\x13|?\x8b"(\x8b\xd6\xa7\xd8\x1as\xd5>\x9a\xadD\xe9s\xfc@nZo\x1cF^\xa3\x1ck\xac\xf8 \\\xd1\x92\xb7\xe42\xb9\xab*7[\xf4\xa2\xe3\x90\xc5i\xa9+sj'
        b'\xc9\x06\xd3\xbb\xc7W\x00@r\x7f\xec{\xd6~\xefRh@$<\xe8R\xc9\x97F\x14x\xcb\x7f\x8a#da\xdb\x88^z\xbf\xf2y\xb3\xfe\xfdw\xdc\x85N\x06\x13f\x92\x7f\x11\xc1\x9a\x8d\xf3\xe7\xeb\xe9\xe8\xbe\t '
        b"\xc3\x0e\r\x9e\x18\xe5\x8b'\xb0\x11}\xbc^\x997\x82\x98^GH\x901\xee\x9ctL\xb6B\xee\xa4\x94\x1d\xd7\x14\x1f\x11<2w\xff\x15\xfb\xbb0a\x97\xe5\xf4?&\xa4\x89\x95\xe2\xc5\xc8\xf5\xf0\x90\xad\x9fUM\x9d"
        b'\x07\xfd?\xee\xe4\xbe\xf2E\x07g\xba\xe97\x96q7\xc9\x84NA\xd0\x84\xe7Hl\x91\x8a9\x94\x19y\x1b\xc1\xeb\xc2\xd0\x1d\x1e\x02e3k\x1e\x1d\x12*\xa5\xb1\xcd\x0f\xcf\x90\x86\x83\xcf\xba\x85\xe8r\x91jr\x1a\x8e'
        b'\xed\x03\xd5J\xf86\xa8*\x1f\xa7\x92\x9cG\x93\xbfY\x0f\xb3\xdf\x0fq\xe2\xc3\x03AtW"\xf6\xa4^\x1asz\x84\x16\xb4\xd5\x99\xc1`Ff\xefa\x8c\x96\x90\x86@\x84(\xb4\xdf\x880K\x95+\xe5\xc2\xa1`6'
        b'{\x12\xe9\xe9\xf1:A\xd2&v\x84\x86\xbe\xe2|H\x00\x9f\x0e\xbf\x0f\x18\x8d\xa2\x97\xe0\xaa\xb9\xcfM\xd8\xdc\x81\xd55y\xe2D\x1a\xa6Q\x9c\x0b6\xd4e\xe3>!\xe5a\xf1\x1b\xed\x1a\x99\x19\x83z\xad\x9aaz\xc0'
        b'Z\x01o\xc0*X\xa0\x0b\xc41*\xe0R\xccy\xaf\xd0\x0e(g\xb7>\x87\xc0\xe1\x16\xf2\xef\x8e\xaa\x90\x82O\xc1\x84\x99\xf9W\x97\xa4\xa1=k\x04\xfa\x19\xe1\x0fT\x166$\x9a\xf4\x1f\xbajS&\xc4\xe9\xb8F\xe2'
        b"\xdd\xb64l<\xd3\x19\x15\xd6A'\xf39h\x8c\xb0O\xb6v\xe3\xaa\xaa\xbbVv5}\xe7\xa0E\xda\xe2d\x10\x87\xae\x91u\n;{\x92\xd9!\xb3\xc7\xdb\x03K\x15\nJ\xb1\xaf=\xb4W\xa3\xd1Y\x87\xb6\xado"
        b"\x8e\xa7\x1b}\x9c\xe3\xfa\x15\xaf\x868\xeb\x9d\xc7M\x0b\x93\x86\xde\xa8\xfb\xe8\x10;'\x1aRW\xd7\xc5*\xea\x13@\x8b.\xba\xd6\xe9\x12\n\xf2\xb3\xbe\x80jR\\\xc3\x1d\x9c\xb4\x8f\xf6\xf0'9$ sh\xe7\xc96"
        b'\xe3-HS\xd0Q\xdc\x7f\xaf^\x9b\xf1\xb2\xc9\x01F\x1d\xbe\xf35\x9a\xa6\xca\xa0\xac\x86\xd51\xfb\xbdcU\xe6\xecVu!\xbc?\x1dr\xa2\x86>\xbf;U\x0f\x8a9ca\x14\xad6\xc3\x1fl\xee^\xf9\xe6\xb8\x07'
        b'\x01\x05\x0c\xef\x80"\xda\xaf\x97\xd5\ne\xa5\x1b\xb2\\\xa8\xa2\xa5\xb1\xbe!\xbf\xf6\x14\\G\xb4Ss\xc7\x8dn"l\xc0~&I\x1dlI\xbf\xba\x15u\x90\x1d\xdb\xec\x1d\xa1\xc6\xf5\x1f\x92\xben\x99\xd8,\x191J'
        b'\xc3\xd8\x17\xc9\x80\x9c\xba\x18aD|\x14\x90k@e\xa2]\\\xd1v\x1d\x97\x18a6\x12 2\x11\xcf\x8aw+\x1a\xc8\xeb\xf4?N\x07\n\x89^\xad7v\\\x89\x9b\x17\x85o\xe8\xd3t\xf0\x9e\xcd\x04\xf2\x16P\xeb'
        b'^\x88\x84\xb1\xde{\xcfh\xc4\xc9\x82\xe0\xbd7\xe8\xe1\xd1}P\r\xdc\x7f\xa9\xd6\xe3|\r\xcc\xf8\x8b\xd0mB~e\xb2T\xa4\x8dU\xce\x93\x08=\x98\xcb\x1bb\xba"J\xf6\x08\xa5\xb2F\xd2$$B#\xb8\x19\x03'
        b'\x7f\xb4Uy\x92\x145 B.i\x02\x9b#\x88)\xc5`\'Y\xef\xb6\xd3\xa8\xbd\xce\x97\xf03}\xdaP\x9ak\xb1,\x9e>\xbdC\xa6\xf0\xb0z\x06\x98j\x9cX\xa2\x93"S\x044\xd7W\x0f\xc7\xb7@\xf46\x16'
        b'\xe6\xd78\xfa\xfc\x80\x9c\xbbb\xbc]\xb7\xf0,\xb2S\x06"\x8c\xee\xda \xbf#P\xe47\xb0\x81P\xa18\x14\x1a\x02\xac\xe7DV/\x1e\x8a[C\x9b\xed\xcf\x1a\xdb?r\x83@J\xcc\xc41\xa3[\x13\xfeo\x18r'
        b'\x92\x9e7\x00\xb3\xff9!\xda"ac\xed\xfc\x1d\x18\x0f"\x93\xad\xe3\xf2\xb2%Y\x10\xe1\xbb\xdew<hf\x03$\x83\xe2\x9f\xae\x81w\xd9S\xff/H.\xc6O\xfcpS\x8b\xaf\x85\x8a\t\xe1\xd7\x01>\xa3\x0f\xb8'
        b'\xa9\x93\xc6\xf0!\xfdG\xd7\x05\xe7\xd0Q\xd3\x02\xdb\xb8|\x8d\x921!\r,\x00\x8f\xbcG\xebj\xeb97K\x02\xba\x81\xb7b\xbax\x19\xa6\xafuv\xd7\xa1\x80wO\x93\xd3\xb3\x1a\xcbm\xcb:\x032\x05\x81\xa0\xcc'
        b's\xf7\x81\xc8\xa5K\x87\xa8(h\x1d\x19\xe7k\xee\xacre)?1(kf\xf7\xa4\x9d\xf7\xe1\xf7\x86P\xc8UBq\x92.8(\xfc\x0f\xe1\x88\x12\xae\t\x82\x06\x87\xac19I\xcd\xc897\x19\x8f\xdcTs8'
        b"8\x81\x17\xdb\xb0XzHEi\x17P\xc63\xc9\xb6\xf1\x18\xa2`wk\\j]\xddf(\x85P\x92\xe9\xa1\xc2\xfbq&w\xe4\x80a)\xf4\n\xaf\x0f\xda\\\xc7\xdd\x17/\xf3\xd7R\x1e\xda\xf5\xacE\xda;\xfc'"
        b'd\x99\xbc\xdd\xd3[`T\x12\x17\x9c\xecb\xe4\xeazl\x9c4\xb5\xf9\xd6\n\xe6\xe0\xe2J\xf7p\xb7\xdbc\x86Ga\xa2\xee\xd2J\x10\x15\\+\xcdXS\x03\x1e\x8bH\xdf\xbe\xdfYC\xcf\x1a$@z\x83,\xf2\xf1'
        b'v\xb7V\x0f70{l\xff\x93\xddg\x85\xdbl\xd6\x05\xc3\xecK\xbf\xba\xa2S}~!>\xf5\xd8\x8a\xf6\xb2n\xba\x85\xa2\xd0\x9e(P\xf94\xc8\x16Nk\xd9_\xae\x17\xae_\xdd\x05\xa9\xaeU\x7f\xa9\x97\xf6?\x14'
        b'\x05\xfd\xca\x89.\xfa\xdd\xa3g\x8a1\xb9J\xdfy\x8f\x83\x8a\xf9zfz\xd9)(y\xdb\x1cPg\x98{\xd2Q\x0c+\x92\xe2wu\xd5\xf0\x00\x17\xe5/\x91\x84\x996\x0c\x87\xdf*\xbf\xa9\xd0/\x89-\xb72/\x1c'
        b'|\xe9$\x1aE\x0f\xbd\xbd\x00\x80\x13\x0b\xaag\xe8+\xb4\xa0\xc9{\x03\xc9\x04\xf5\x90\xf7/\x1f$t\xa5\xac\x84+VMvdt\xa8W\x8fW\xc5\xc3\x95?\xf3)\x0c&\x1f\x94Z\xa3\r\xf0\xa6h#\xa2\xcb\xd07'
        b'\x8e\x14\xf0cc\xdc1@=)\xc4\xafJ\xa3\x8b\xb6\xff\xc2\xacd\r\xb2c\xfe\xed\xa9\x84\x9a\x8e\xbb\xd0\xd2\xee\xa6\xe7\x9e\xde\x17\xc1\xb8\x1d\x00\x17\xac,\x16\xb1$\xd1\xbe[\xae\x01\x9dT\x914\xc0\xae\xd0 \xd9\xe0p'
        b"\xff\x8e*\xd9\r\xa4\xdb\x105\x11'v&4\x17\x99L\xe6\xa4O\xd1iY\xce\xce\xef\x07\x9d\xae\xa8\\\xe6\x12\xa9\xf0\x1aR}\xcb\xe9\xf7\x1b\x99f\x10\x95\x19\xe9{\x93\x1dlkU\x98OME\x00\xdaYb\xa7\xc0"
        b'\xef<j\x9b\xdd\x98=N\xc9\xa4\xb8\xd3\xbd\xef\xb8|\t\x82O\x9a\xda\x10L`\xe4\n\xf1\x88\x17rKi,B\xbc"\x0c}\xc3S\xe4\x08M\xf3]\\\xe1\xb9*\x86\x1a$\xc4\xc8r5 5\x00>i\xbe\xe0!'
        b'\x05\xfeb\xd2\xd5(\x14q]k\xd7_q3-\xd6\x9f\xb7\x0f\xc5\x0cn\x19\xbe\xa9S\x86\xf7#\x9cI\xeeX(\xfa\xe7\xaf\xe2\xf9B\x1f\x13W\xcfF\x84\xf6\t\x9d;\xaf\xabm_\x16\x1c\xc0M\xd3^\xb8\x81l\xaa'
        b'k\x05\xbf\xe5\x92\xa9\x80\xa1\x0b\xfb\x12\xc5\xbd\x8e\x98\xb4I\xa2\x031\xc1\t\xb8\xc3<\xc6\xcd\xeb0\x8d\xb8\x9c!gh\xdc;\xf9\x99 7\xa2\xfb\x84\xffVT\x88\xcf\xe1\xf2\xba\x19\x82\xe8&\xf0\x0e\xa6\x07\x95/\xa1I'
        b'\x13><\xe4MA\xde\xf8&J\xd0\x9a\xf9Nu-\x93\x1bXx\xf7Dm\x16l\xad\xe4$G\xfdR\x00J\x12\xf7\xa4CT\xda\xb3V\xec(\xd0\xa1\x9d\xf0\x9d\x08\x10\xaaCA!\xa3#E\xc6\x04\xa2\xf8f ='
        b'\x13\xef\xee4<\xa5\x10CiO\x900\x97l\xf4u\x0b\xa7*\x08\xc0H\x16\xc0\x12d;y\xbbN^\xab\xc8\x83\xd4\xd9\x8a\xa8-\x11\x0b\xb5\x8ct\xb7\xc8\x0f\x88\x88\x83\r\xa272\xf4\x91\xaf9\x8b\xc0\x9f[\xe5\x99'
        b'\xed\xc2\x96fn\x02l\xef\xb8\x9bd;\xeb\x08\x00\x05\x16\xd4\x1a\x1c=\xcb2X:\xa4\xa8^\x84\x1fb\x05\xd2\x91\x88N\x10\xa4\xf0\x93n\x04\xcc\xd2/\xf6n\x0f\x11\xa7\xb6\x80\xfa\xfb\xc1!;\xd2\n\t\xb3\xf86\x89'
        b'=\xc1\xa1(:\xc7Sa:Y\xbd\xf0Z\xe5d9\xcd\x9c_\x95T\x989\x1c\n\x18\x14\x0f\x13\x0e\xdc\xe0\xc8\xd8\n\xaf\x87X\x0b6\xf4\x05~{v6\xe7D\xc0\x0e\x1e\x12\xb4\xb9\x00W@R\xbe\x8fb\xee\x81Q'
        b'\xf5s\xf9b\x8d\x98Z\x0cR\xcf\xaa=\xc9{\xd0{\x85\xaa\xcb\x90j\xbe\xc1aG\x08\x81Yf\xc8y\x83\xf6<J\xa3\xb6+9\x98\x9aW\xb7\x03\xb6V\xeb\xd4#\xbe\x01)\xae\xf9\x94\xf1@1\xdf\xb43\x86\xf7\x8b'
        b'\xe2\xc8\x02\x9b\xd3\x94\x82\xcaM\x8b;\x04s>\x9a=\xfb\x8e\xefaV.\x97\xc4 ^\xba`\xe7C\xb9\xbf!&\x1b(\xb4"\x0f\xb7\x85\xb8\x0f\x15\x90\x10\x14q\x1b\x1dOJ\x99F\x1d\x8f\xdb\xaa\xe3\x7f\x1f\xfb\xe43'
        b'\xb6\x05\xa7\xefN6et\xaf\x9e<4\xacjx\xf7b\xe7\x0c~vV\xbd%\x95\x95\xc0\xa4e<E\xb9\x97B\x7fE\xff\r\xf6\xc2\xdb\xa1z8\x82L{\xa7\x1e\xa2\xf1\x8c\x8c\x03Bg\x81BT\xfa\x8fl\xff\xee'
        b'%\xa7O\xd2~\x9b\x8f\xa0\x9a`\xb1#\x89y\xf0\xe5\xaa\xfaR\x9fQ*\xb2\xfb7\x0c<U\xa6!\xb8\x96\x14\xc9@r]\x99$\x8a2\xed\xa9\x99\xcd\x1f\xe6\xa0v\x9cj\xd34\xe3\xe6V\x883\xee;D\xd4f\xdf'
        b'\xe7\xb6\xe9\x04\xc70\xf4k+\xa9\xf9l?\x1abE\x89\xd34\xb3\xe9C\xc1\x97]\xe9.R\xf5=\xb4\x1c\xb1\xb2]!\xb7E\xc3\xb5O;\x8f~Y\xcb\xd5\xc3$\xbc\xc46\xbdMPZ\x88\x9d=\x90w\xd16%'
        b'O\xc3\x1a"\xc8\x81\xcf\xf1y4\xe6T\x95\xbfh\x89DC\x84S\x926RoZT+\xae\x1d-\x03\x94"\xb8O\x8b\x82\x0ftf)"\xb2\xe2W\x00\x88\xf6\xb7\x02R\xe2Vq\x1b;\xd3\x81\xa3x\x00\xce\x16\xf2'
        b'\x05&p\xd8w\x8a\xc8\xff\xb3\xc2\xe4\x0b\x85\x8a\xd1\x9e\xa1\xd4\'\xe9\xb9\x92\xf6\x0f\xd71\xdc\x8c\x167\x8c"o\xcd\x92a\xa5O\x987\xb7@\xdb\xad\x9e\x8a3\xd9\xaf\xd3\xa3P1\xa1\xc9\xda#9Qd\xadD*\xeb'
        b'\x8d.Y\xd2\xd0\x8b\x18\xd6;\xc5\xc4$z\x9f\x15\x14M=Cve\xde\xb1\x05*\xb4\x9d\x0f\xc2\xab\xbf\xf5\xe7\xf9\xc0\xa6\xd1\x17\xdb\x1d\xaf\xdez\x07CmI\xb8\xf3wj~a\x01-\x07\xec$\x7f\x9cu+j\xa1'
        b"\xe9\x017\x97\x98\x83\xbd\xbe\xff\xce\xdb\x08\x83\x88\xb0\xccq<\xa5\xe6o\xf2\xae\xb8\x0b\xc8Q'\x11\x15\xdd\xc7\xa0\x9cR\x92=O\xf9\xe6,\x85\xfc\x8eJ\xab\xfa\xc5xu\xe2\xd1U\xa3\x8e\x9d\xf58\x890\xa7\x98\x01\x08"
        b'\x0ev\xd0\xb4\x0b,\xe0\xe15\xb0\xe3\x7f\xf8\xab\xb4\x96\x88\xd4\xb7\x18}\x19\x8b\xb7j~.E\xd7\rE,\xa6\xaa\xeb\xa6\xd7\xe0:\xe9F\x10\x97\xa9\xa0\xfd@?\xb8s\rd\xdd\xca\xde\x87J{\xd6\xa2\n\xf6\xac\xe1'
        b'r\xc9\xa0\x84_\x98\xc7=\xc2\xeb\x1c\x8dy\xe1\xdew\xf6J\x12\xea\xd6.\x9dB\xb3V<R\x0c\xfb\xef\x11F\x84#WCl\xfa\xf6m1\xeaQVM6\x92\x0fMV\xa8\xdft\xca\xfe\xe1\xd1c\x03!\xe7\x1d3'
        b'hp1&r\x02\x19\xa8\nyWG\x8a\x08*\xe8\xfa\xffO.NE\xc6\x15\x81\xec\x01\xa1\xf7\xa5\x94Zy1\x8b[\xeed\x03\xa2\xda\x0b\xff\xd0W\x82\xc7\xbf\xee\x85\x87\x9eb\xe6\xdd\x0e\x00D\x97\x96`w\xdbx'
        b'p\xfe>G\'\xf7r\x82\x93\x8c|L\r\x86\xff\xaf\x95\xf9Q\x02"f\xb2 \xe1\xf7\x87\x02\\z\x1a\xcbZ\xf3h\xe1\xbeTE\x9ar\x19\xe2]\xe8\xa1\xd0\xf4\xc3oD\xf5e@\x9f/\xf9\xc4\xaa f\xc6\xd6<'
        b'\xeed\xec\xba\xfd\xb94J`\xa0\x89\xbfA\x93\x19\xd95>]\x14\x8do\x0bm\xc5u,\xcfGy\x1e\x9a(>C\xc7\x1b\xbd@\xec\xd6Y\x0f\x07?\xe9\xdb"\xea?\xffiI\x92g\x1a\xbfbm\x7f\xaa{\xe9\xe0'
        b'\x9f:\xcc\xa3\x9d]\x82\xdc\xd0+\x8d\xf2\xe5w\xaa\xf2\xef\x15d1\x9b\x14\xc9\x03\xf4\x1b\xb9Z\xe5\xcc\x00\x14\xeaN\x12\xbf\xe9\x9d&\xbe3\xd3k\x15S\x96B\xbd\xa5\x83uP\x84\x924r5\x1c\xae\xfdx:K3'
        b'X\x0b\t\x11\xf1C\xdb\x05\xb0\xcc[\x9c\x9b\x8aKo\t\xaeV\xcc\x03`\xe4\rrO\t%\x13\xf7\x8e\xb8h\xad\xb3\x80C\xa2\xba0\xf5\xe9^\xa5\x85\xf7D\xaa\x91(\x03?\xd4\x01\xcf\x00\x91\r\xe1\xbf\xc4\xad|\xb6'
        b'\xbf\xe4S\xcc\xe8\x847\xe0\x9b\x0fM\n\x04\xa4\x80\x96{l3<\x12;ak\xac\xd5\x16w\xa6\xccJs\xf0-\x80GkbR\xd5${\xb1\xc9\x88\xb9\xee\x0fN\xc8hj13\xe0\xe3H\x04\x94\x8c(\xae\xf0\xc8'
        b'\x1d\x1f\xa0\x16\x86\xec]\xc7\xc8\xddN\xa7mR\xaf\xed\xad`uO\xad\x14\x9e`\xc3?\xd5\x02\xd6\xa8\xa8\xd8\x00\xfd\xea\xcd\x11\xde[o\x00|}\xd3\xdf\xdcUO\x1au\x99=f\xd3\xf2\xd0\xffP\xb5\x91\xc0\xe1\x9e\xe7'
        b'\x11\x1b\xf1gs{\xfcQ\xb2\xde\xb0x>n\xf9\n\xa1\xa6*K\xfdK\xab\xdaw\xc8\x15\xce\xa4\xbf\xb7\xaf)\x91KK]\xb8\xaa\xcf^\x8d\xdd\x08/\xf0\xdb4\x14\x80gr\xa8\x8c\x1e\xc5M\xa9\xbb\x008i\xbfa'
        b'\xff\xb5\t\xe5?\xd5^\xf0gd\xd3\xbd\xefg\xd4\x0fG\xa4Y\x04p\xad\x86V&\x87\xae\x92\x95B`\xe8^\x8d\xf6\xf7\xd6\xbe\x93a\xa8\x87\xb7:\xd2\xd7\x16\xe0\xc8\xe1\xba^\xd5\xc6\xfa\xe6A\xc5*\t\x96p\xa9\xfa'
        b"\x84q\xea1\xb8\x83j\xf7\xb8~b\xf9'\xeesX\xc4\xa8\x9f\x83#J\x06\x9d\x9b\x07\xfa<S\xd5\x14\xc1\x1eRy\xbc\xe7h\x9f\x13((\\\xc9(\xdd\xcf\xef\xf3c\xe2\x85\x15!\xdc\xc3$\x8e\xcb\x1b\xbe\xc0[u"
        b"=\xaf\xcd\x83\xc4\xfb-\x83\xfb\xa2P\\\xaf\xd3\xf6w\xef\x85\x9dJ\xcc\x9c\xec\xacEM\xb0\r'z\xc9\x8e\x02qE\xc4G\xda+\x1d\x07\xbc\xc98\xc5\xab\xaf\xf9PW\xd3\xb4\xdd\xa6$\xf3\xda\xf9\x1a\xea\xd2\xa4\x1e\xb6"
        b'\xf1\xe6\xf3\x87\xbe\x87bv\xfcr\xaa{\x08\xeb\x85V\x9c*\xb3 9\xef\xf4\xeb\x0bT\xa9y\xe8\xd8\xd9\x1c\x91\xf7\xd5$M\xe3\xa0\x91\x12\xe8\xdb\xba \x93)\x06\xf6\xf1\xc2&\xa6\xaeF\x8a\xa2\r\x9bp\x97\x02Y\xbb'
        b'\xc5\x91\x0b\x8a\x93;\x80\xc9\xc4O\x87\xb5o\xe3\xee:\x90\xb3\xa9\xc8"D8\xbf\xdf\xdes\xb5\xdf\xe4\xf6\xa3\xd3\xb4\xa8\x8b\xb7\xebcL{\x00\x8e~P>q\xab\xe2\x9aJ\xfc9\x0f\x9f\xa62\xad\xa2?\x02Of\x90'
        b'\x0cg\xae\xe9\x05\xfdx\xf6L\xd1T\x88\r;+`>T\x1e\x0816\x1a\x16\x8d\xfb\x0f\t>D\xe0a\x94\x05\xe3\xbe\xc6\xe9\xd9\xd7)<\xd8_b\xba\xa4\xc4\x1e\xddK?\x17\xba\xf7\xe1\xd72y\xf7\xf4\xa5\x14{'
        b'\x0c\x8e^\xc6\x8b\xfdh\x81?\xe8O\xf9\xb9\xa9)\x0c<\xaa\xe6\xd5\xb9\x1c\xe1k<f\x80\xbc\x00l\x8b\x1a\xbaz\xfc\xc8WZ4\x02\xee\xa7\xb0\xe1\xff\xe7niM\x1f\xebnhK55_\xa1u\xe4\xa1\xcb\x08R'
        b"\x92SxY5\xc2\xc3\xb0\xc4\xb9\x99\xf0\xc0{?\xf5\xa2'\xd5\xbcg36\xf1\xad\xf6H)\xfce\xf2e\xa1+\xfa\xe6n\xfch\x9dA\xa4S\xaa\xc91\xc8\x82\x82mI\x00\x03\xad\x99w\x0f\xbd\xdf\xc1\xae\xa6\xe1z"
        b'N\xc4\xb3B\xfa\x0f\x92\xa9\xddQ)\xc8\xa6\x01\xf1\xde\xb3$\xe3\xc2\x94\x82SM\x19\xa3\x15\xf2(*_KT\xbb\xf8\x91\x82\xd7)\xd9zO\x8d\x95\x0b\xab9\x9f\x9d\xebz#\xdbo^\x14oV)\x1f\x8dS\x9f\x8c'
        b'\xcf\xf4\x14;\r\\{\xd9}t"^\xec\x1arl\xf8\xb7]e\xe9+icue\xcd\x16\xdb\xdc\x03\xc2\x00\x8e\xce\xf3\xb2\xfa\x1czu`\xd1\xc4\xb5\xf3Z\xa2N\x8d\x10<\x15@\xc5l\xc3"\x16\x10M\xc8\x03\x96'
        b'\x13U\xf8\xb1\xa4nNU\xae\x91\xe7\xa5e&\x99sK4\x8aR\x1d\xf2\x8c\xbd\xbb_\xb1\xa4\xe7\xa1\x93\x86\xc7\x04\x07\x98y\x0f\xce\xeb\x0f\xe9\xed\x88k\x8f\xda|U\x8c\xa5\x0c\x17\xe3-\xea\x82\xda\x8e5\xc4\xe7\xbcZ'
        b'\xd5\x9c\xae\xf9\xc2\xb3Rn*\xf75\xf4\xc4\xca\xfd\xc0\xf7\xbf\xb2\x8d\x173\x12\xc7je\xd7M\xa0\xd5\x7fs\xfb\x925\xab`ec%u]e\xb5t"\xf3\xc1K\xbb\xce\xb0\x0ea.\x88\x1drYV\xa4\xd2|\x01'
        b'e\x06\x84\xecRx\xea\xc6\xb7\xeb\x00\xdd\xea\xefI\x86\x08&8\xbfPD\x91e\x9d\xbe\x9d\x9b\x1b\xac\xc5s\xcc\x12\xb0\x0c\x1f\xe7\xc2h\xad-n\xea,N\xda\xb4+\x8fP)\xca\xcf\x01\xe17\x8d w\xf3\xd5\x83\x95'
        b'\xa5\xa8\xd8\x12\xeb@\x0fc\xa1\r*\xc1\xe1\x04z\xcay0T\x94\x13\xfa\xd1\xc2}\xfa>2\xfa\xd0\x99?HW\x1eh{\xd8\x1cD\x1f\x04h\xb3\xcan\x1c\x19\xd6\x8c:\x1e\xef)~Nx\xdb\x87\x86Q\x12!\x12'
        b'\x19\x1c\x0f%\xf1)16\x0c!\xea\xbd\xd4\x95\xde\x1aZ\xfd\xc6\x8f\xa2\x8a\x89\xd6\x8f\x8e/J\x17\x17\x86\xddHdq\x0ev\xb3\xf3P\xcc\xdd{\xe7B9\xf39\xc2\\Nh|c\x13\x06\xfc\x0eAG`\x94\x84g'
        b'o\xb19D\x81\xa8\xd7\x99N\xcfIB\xee\xac\x8a\x83+\x027\xabIep\x16\x94\x05\xc4\xbb\xb5\xb4\xf8K\x1c\x1f\x01W\xe6\xea\xec\rtu\xb2\xd4>w\x1b\xbc\x1d\xfb\xe3\x1c\xa2N\xea1\xdd\xb2\xcd\xd2\x1c\xf6\x8c\x0c'
        b'\xa5\x0c\xfczs\x04\xe8\x881$\x18\x8b)M\xba \xcfK&\xf2\x89\x90\xa40\xb3,\x0fKj\xa1\xa2M\xa2n\xb8\x80\xf6Q\xd9\x9d\xb1\x86\xd4I\x81\xd5\xe15\xa0\xfeT\xfd\x1d\x92\x0c\xac\xe9m\x92\xcf\xebg\x0b\xfd'
        b'\xfb\xa0\xb50\x19\xf0vj!\xbe"`\xc5\x8c\xa3\xa3\xb8Q\x83\\\xc0(zcd\x10\x94\x99\x9e[\x88\x1c\x80\xcc\x99p\xd7\'\xea\xd1 -\xb1\x11\x17\xf4I\x14\xa2\x9a\x16\xf6_\x97\x8f\x84\nFi\xae\x14\xef\xbf\x1f'
        b'\xc6\xfe\\\x92r\x9b\xe5\x85\x11\x90\xb3#\x1cs\xb2<\xc3\xce\x02\x9e\x1f}\x98\xa5nE\x80\xa7\xf4\xd1\x9f\xb5\x18KQ\xf2\x91\x8ba(\xb3\xc9\x9fO\xe8\x0f\x83\x1bp\x85\xc1\x8c\xa8\xe1\xdbZ\xed\x1d\xa9\xbd\x03h\xfc\x95'
        b'\xcf\x9d\xd5\xc5\xd3\xce0\xf7\xac0et\xb0\xe7w\x03N@4\xcb\xb1|d\xb7\xcb\x0fv\xcf!\x17e\xe4yIe\x01<\xde\xad\x87h\x7f\x1c\x8dD\xaa\xd6\xed\n9?d\x98C\xe8[\x1f\xd3XgEY%\x96'
        b'\x89\xfd\xa92\xd8\xce\x86\xc6\xfa\x9c=\xd1>@\x8d\xab\xa6\x8d\x02\rsR\xb17\x98xs@yJ\xbe\xe5t\x1d\x13\xe2\\\x7f\x8c\x0e(\xa1\xe2\xc9\xae(\xef\x8aK\x1d\xca\xeb\x1a\x8b\xa7x\x93\x82\x9fE\x81\xdf\xb9\xf1'
        b'\xfdd\xda\xb1lj`\x86_s\x19\x9a}\x15\x8b\xabe\xb0x\xf7B\x90[\x19\xa07V=\xbd,\xd9W\x1at.\xbf\xd9\x89<\xf5\x03Ub\xc7-b\xf3=\xd2N\x8d\x1a\xef\x00C{a\x8a]5\x8d\xfc\xaa\x07'
        b"\xbb%fyT\x91='\xf6\xbd\x81q\x04S\x81\x9d\x0c\x9d\xdaYuu\x1a\x01I[\xefZ\xce\xf6He\xd4\xbe\x8e\xb3\x1f\x9d\x0e\xbe;\xefp\xd7\x9fo\x84UL\x0fo,\xe1ur\x15\xde\xc9\x89d\xbf\x0f\x81\x13"
        b'\x14#\xa0\x95\x16\xcf~;\x8e\xd0\xe2\xcaCt\x04\x89mJ\xad\x0f\xb5\x17\xd5|\xcb\xf8X\xfa\x92I)G9\x96\xa2\xa0\x92\xd8b\xcc\xbf\x8b_\xca\xd1M\xf2\xbap\xdea\xc2\x16Z\x0c\xc9\xde\xa9)\x12G\xd5 .'
        b'\xcd6\xe2\x01\x17\xdc\xcd\xd1\x07\x05\x9b\xe9J\xbf\xa1\x0c\xcb\x14Q\x81\xc3\x81\x8d\xc9D\x18\x7f\x7f\x8d\te\xf1%5_h\x1a\x90\x9a\\\xa5[i\x98gfr\xf5?\xb5_\x00|`A\xda$\x11\x9ad\xf2\xcd-X'
        b'\xab\x18-\x9a\x0c\x11\x8b\xaf\xdd\xaf\x02\xc8/iYe\xcd \x84J\x0b\x90_\xe6\xf7\xb5\x93cs\xa8\xe6\xbc32+-w\x051\x91q\xe0\xa4\xa5\xfb\xe7\xdb2\xe2\x18\xce10\xc1\x12a\xf4\xfe\xac/\xec\x8b3\xbe'
        b'\xf8\x81G`|\xf5\xf9\xfe\xb6\xceK|\xc4$$\x80&q]\xb1\x94\xa8\xa0\xaa\xcf\x9e\xe5\xee<\x8b\xc0\\\xf5\xeapW\xeb\xe5\x8fBc\xf3\xf0\xbe\x91\xe3"n\xf8\x0c\x8e\x12\x14\xbb^;+\x8cq\'\xcb}k\xb1'
        b'\x91\x80\xb3\xed\x83\xbbb\xfeX\x9dC\xc9M\xce\xc4\xa1\xa0\x07:Z\xdf\xd9\xf4hS0\x190@\xf3\x14&\xec|\xe5\xf6\x80D\x9a\xacz\xb7\xbb\x01\x9c\xdf\x9e\xbb\xbe\xfc\x91f\xcd\xdd\xafQ4\\\xc5^X\x82\xa0\xd9'
        b'p\x15v\xa2(\xd2=\xc5D0?|du\xe22y\xbcs\xbe`\xea\xd0\x03\xdd*U\xb0\xd5\x9e8\xcf\x10\x8c\xd9\x81:uw\x9ft\xa7"\x83Z\xe3\xcd\xa3\xfe\x1cA\xa5\x0e \xf3w\xdaJ\x93\x0bO\xb0\xbe\xcc'
        b'%\xbf\xc2\xb7-F[\xb1,\x1d\x12uA\xdfK\xb6<\x11L\x92\x92\xfa\xabU\xb7\xea|\xdcX2\x85\xcdA\x03\xd7\xfe\xebM|\xf1\x01\xbc\x1cI\xc4\x9b\xadh\xa8\x17"\xdd\xe8\xf2T)F\x9f\x92\x91G\x12\x04I'
        b'K\xec6\x04\xbc\xdaR\x16\xff\xd8\tx\x9d\x85\xaf\xeff\xba\x98K7\xe0h\x83o\xa5\x0e@\xb1\xeb\x8c8}\x02\xed\xd61\xa8sr\x8eNCQ\xf0\x02\x00y-O\x93\xf8\x81\xf1\x02\x88\x9b\x9e\xd2RQ\x0f\x80\xf3'
        b'\x1a\x9f\x96\x85^a\t\xaa/l{\x1d\xcc<\xa8.\xc9\x0b\xe4\xd9\xd8\xce\x964\xe6\x98\xf7Y\xa3w\x04\xdd\xf3\x04\x98?x\xe7\x08\xaa\x8b\x071\xb5,4\xde\x9f\x00s\x15R\xda\x8f\xe8\x12\xf7"\x05RC}\xc5\xb6'
        b'\xb3\xa7Z\xc0\xed\x87\xd9+\xe5\xfb\x83[p\r\xa8\x9c1\xddly3Hz\xe9\x1d\xfb\x9bV\xbb\xb6<\x837\xe9\xa4\xe2*\x14\xf2\x88j\xf4\xf0 \xec;\x84NOL\x87\x85\xca:Wc\x0b\x18$%\xeb\x99\xb8\xe0'
        b"\xcc\xca\x90\xf8\x1a\\\xbe\xf1@\xc17Q\x1d%7?G\xf5\x84h\x86`\xef\xe4\xdf\xde\xa4\x07\xc2\xc0\xc7\x0f\x1e\x8f\xbc\xe5\xe1\x05\r\xd0%\x005S6\x12\xb6\x84\x8d~\xedR\xaa\x07'@-b\x87\x17\xb8\xf6\x1c\xbc"
        b"E\x1fTV\x19t\x11\xf9\xa7jt\xf7(\xe4\n\xcf\xe6\xa7\xe5<<~N'v\x06n>\xf5.\xcf!\xb8\x14*i\xe5\x85\x13\x9f\xb2\xa1\xd3\xbaJ\xb1\x13\xeb\x89\x7f\xeb8\xdd\xd4\xc3O\xfc\x00\xa2\xd1K\n\xca\x00"
        b'\xe6$\xadl\xed\xdf\xa0\xf9\x9c0\xed\xf2\xf3\xc0\x86M\x19\xa3XPS7&*\xe148\xd5\x10a%\xd9rq\x83<R\x03\xe0Vu\x98#l\x1a\x11\xe2,\xcec\x07xW\r&so<\xb0\xc6\xb0\x04\xa8\x8f'
        b'\t\xa2\xfc\xb4\x8e\xd7\xc3xS\x0f\x98B\x9d\xab\xa47%\xbd\xeb$\x02\x04\x9b\x0c\xa2Z\xd9\x80)Y\x1eN\x9f\xb9P\x8aX\xae:t\x92n\xef\xb4r\xd8Z\xd3\x1d\xbel\xea0_\xf3\xb5Z$i+\xb2v\xbd\xba'
        b"\tUH\xf4\x1b\xcb\x19\xb0\xf9!\x9cY<H\x9e\xd1Y\t'\xa1\xb6\x91\xc3\xcd\x17\xb5\xe4\x15E\xdd\x91\x8ay\x1e3\xe6\xb7?\xae\xd4r\xdd\xaa\x05\xc4MU\xb8\x1f\xaa\xb9\xd5\x92\xc0\x04\xd9\xc4.\xf9\x1f\xf9\x126c"
        b"\xcc\xc5'=S\x96\xebV`\x83=\nR\xbdp\x81`\xa7iTT0Xd\xec\x8dfA4\x1e\xec\xe2 O\x9f\xc5G\x14\xbd\xc4\xacWy1\x89\xe5\xa3c%\xa4\xdf\x16\x92#\x0bT\t\x9eL\xad\x02\xef\xb5\xf5"
        b'i\x97o\x80\xe5Y\xa5\xc5\x88q\xde\xe2~\xbep\xda)\xb1:\xda\xdaa\rp\x02\x03\xdd\xcd\xe7:\xe6\x02\xe1\xcfL(\x8c\xb2%\x1f\xbaX\x1f\xb7\n\xf9!y\xbc\xa8i>0\x14T\xbcg:\x0c=\xde\x85\xde\x97'
        b'\xeb\xf0Ti\xb5\xe8\x1031\xfa\xe3\xb7a\xf3mq\x1d\x86\xf5<\xedyRn\xff\x94s\x9b\x97\x12\xb5\xcd\xe2\x9c\x80+\xe1\xc8P\x13\x87\xe8-E\xd6\x99y\xe2\n/\xa9[@\x01\xe8\x1d\xd1.\x10\xf6F\xdaZ\xd2'
        b'y\xee\x89\xbcUF\xde\xfc\x03\x9c\xb5\xd9O{B\xa2\xa3E\xfe\xbbO\x1de\xb1\x95\x8d\xf4\xefcAz\xed\xedA~\x9b\xd2\x1e=\xa8\x18>\xdf\xe69\xca-\xc7\x06\xa0%w\xbb*$\x0f\xd0\xb1;\xd6\x1f\xac\xc4\xa1'
        b'\xfbR4\x19\x04\xe3qs\xf3\xb7\x04\x01\xa7\x1f\xe8\x99j=\xbf\xe6\x94\xe4c\xa7\x98\x04\x8c\x91z\xf3 \xadH\xbcSyi?yt#\xbc\xae \x9e\xbb\x10\xa0J\x08\xd1\xb1\xeaX\xfe\xda\x04_Y\xf3\xe1\xean\x80'
        b'\xbe\xfct*\xdd*\xa2\\n\x1f O\x13\xd8`\xea\xe6\x19\x7f\x90\x9b\x8e\xa2b\xef\xabV\xc5\xdb\x8e\xbd\rB\xfa\x1a\x84\xdf5D1B5\x0e8\xacL\x7f\xe3\xbe\x11\xb5\x91p\x00\xeb\xfd\xb3.\xc8i3\xaf\xd0Z'
        b'~\xe1l\x078\xddy\x15\xb7\x06\xf9\xf2\xd2L\xa9\xfd\xe3\xe2\x0e\xe7\x06xd\xba]\x84\xcb\xaa1P\xdezpQ!\xb1\\P\x1c\x99\xfa\xbf\xec6\xdd\xc3U\x9c\xbc\xea\x03\xc3\xc3\xce3\xe9ZI$\xfe\xc9%\xc2\x13'
        b'\xce\xd3\x13\xcf\xf5B\x062?\xa4\x92\x94$fYZ\x16\xfcw\xed\xba\xa3p\xe4\xc1\x8b\x17B\x96\xf0\xbe\x1eU\\o\xad\x9c\xf7i\xec\xb2\x90\x9b\x04q5m\xc88\xa5\xc6\x05V\xdb\x06P\xa7\x9b\x0b?Q\x90\xc1\x07'
        b'\x9d\x90gF\xb8\xde\x9e\'#\xcb\xb5>b\xb7\xa9\xea\xd7\xd8\xea~\x19Z_\xa6\xca,\xdb`\xc3\x13XQ\xf9"i\x93\xe4r$R\xd9D\xcb\xc1\x87\x07\xd3Z\x1fH)t\x12f\xaaXk\x85\xb5"c\xcdre'
        b'\xf9\xa2\xf7\xf9\xe1\x12N\xa9\xc2\x18\x06(\xa2b\xe5\xcd\xc5{1?^\xf5\xd3\x1cV\x97y\x10\x80#wh\x98\xa5\xa4D\x96\xa7\x10\xa9\t\x8bb\xb1,J\xc8o\x89\xdb\xd5?$)2\x8d\x9auw\xdd\xe2\xb1t\x04'
        b'\xceIH\x10\xb5\x94\x80\x89\xae\xb6`R@\xf0\xe4\x07\x83\x03t\x7f\xb1\x88\xf0I\xbd\xef\x90\x05\xa0\x1d\\\xcd\x17\xe8\xd9"9\x1c\xe5p\x8f\xa39\xf9i3\xd5\xc8n\x90,\xb8\xb8\xcc0\xf4\xe0\xbe\x0f\xb2M\x85\xcc('
        b'\xf4\xb3\x05\x1bv\xdb\xefQ\xact,\x91\x05\x01\xdc\x82/\xa0\xfd\t\x02\x85,\xbbrd\xe8\xb4h\xf6.\x02\t\xe2\xd7\xa8\xab\x0e+\xa1F\x18\xa0\x80\xc8d_\xa98\xb5<\x9b\xa7\x11\x06\xe0\xc9\xa7\x12\x1a5\x1f\xf1\xec'
        b"M\x99x\xfb\xa3\xe2\xba\x92':r,\xd9\x87\xdb\xa3\xec}\x91\x8a\x94t\xaf\xcfe\xe6lG\x13(I\xcf\x9fFI\xe5\xd5\x83V\x95\xda\xfe\xb7\\\xf79n\xad\\2(`(\x9d\x07;\x98\xb6\xcb\xcaC\xc8\\\xda"
        b'\xc2\xed\x19\xb5P\x88\xb4\x90\xb5\xf2\xd7\xd9N\xbd5Q\xcbO\xf8\x97\xe7\x9f\xe3\xcfW\xfe[T9\xf3`\xd5\x96$_V\xd2\xf8\x1d\xc0\xa9\x18\x8d\x01\xf6\x8c\x113\x1e\xa9}\x12\x91\xdf\\|<\x8b\xe3l\x97\x0b\x94\x1b'
        b'\x87\xc1\xbd\xb6m~\x1503i\xccq\xeeg2\x04\xd1R\x81\xd1\x1e\xa5\x1e_\x15\x0e\x99\xd3\xc3\x85E\x15\xf6\x1a\x92\xdcM\xbe\xfa\xb5\x00v\xe7\x85\t\xa4\x01\xeax\xd7\r\x1a\x8e\x14\x8a\x82\xda\x97\x12\xac\x91\xd5\xb6!'
        b'\xdc\xd2h1e\xfaj\x91\xf1k\x1d\x89\x9eya\xa7\xfa4\x7f8\xa8P\xcfG\xd4R9\x03\\\xdc`\x88\x8c\xcdMp\xfc\xa1!\x8b\x8cFS\x00\xc2&#\xc5\xd6j\xe0I\x17\x9do]:\xb3\x1cY\x12\xae\x80\x95'
        b'\x89.\xe4\xd1!\xf7\x11\x1d\xd9&\xa8\xa8L\xda\x9c\xd3l#\x18n\x1c\x18\x9e\xa4\x17\xa6\x14N-\r0X\x8c\xb8\x06\x96\x9a"o\xdaDm\xd96\x8b\xcf\x05\x80\xf3\x98\x84e\x8c\xdaa\xf7\xfa\x81\x08@als\xb9'
        b"\xb9g'\x87\xeeh\\k\xbd\x85\x91\xcb\x93\r\\.Q'\xba\xed\xbcg\xca\xa2`\xd8\xf5n-\x0e\xe9\x03R\r(=\xb3F\x9c7~\x885K\xbbX\xd1\x91\xf5\x877\x06\xee\x01\xbd\xc4\xb1VL\xa6\x06\xdd\x9d\x1d"
        b'\x9dC\x04E|\xacZ\xd08\x8c\x18\x0f\xf3Qf\x11\xdeF`9_\xd0\xb1\x92\xf9X\x9a\xf0\x80\x90\xc2G\xab\x01\xf0\x01\x9b\x9e\xb8\xfdz\xdf\xfa\xe1/W\x02Pd\x0bI4\x8c7\x96\xe7r\xbbY\xd6z\xe1tI'
        b'x\x9d?\x08$~?\xc6\xd6^\xf9g\x7f\xb7.Qi\xe7&\x88\x01\xac\xe1Z\xc2\xccxL\xe6\x0e\x83Rq\xa0\xf7j>0 \xe7\xf9b\r\x80\x8a\xc2\xa2\xb0\x80BE\xa3.%\x1b\x84\xea\x8d\xab\xbb_`V\xd1'
        b'_\x85~\xc9\xbfJ\xe2\xe1j\x8fy\xb5\xca\x9f\xd6bz*o\t8\x88\x8f_\x04Z\x94\xb8\n\x14\xc2\xc0Y\x12+k\x91\x08\xbc\x04\xce/\xa4\x87Qq\x0c\x16\xa6\t\x1e\xa7$\x1a\x90X\x9dz\x96%<\xff\xe6\x06'
        b'$u\xe8\x19\xe2\xd2\xb9\xb8\x89_\x00\xc5\x85\xb8\x11\xf2+]!\x8e8\xc6(U\x86e\x95\xddF\xea\xe5\xa3\xd2\x80\x12\x03\xe3\xf30\x02jb\xf8\x82\x81h.\xde@<\xa4\x9f\xec\x8d\xc3\x0c\xb1,\x93\xad\x81\x1d\x13\x00'
        b'I\x9a\x7fRY\xd95\xb1\xc3\xbd\xe5\xf2\xe0Z0\xceTb;\xf6Dy_\xa2\xe4B\x14\x17\x81\xa09\xd0\xb2\xd7j\xaf"Y\xabs\x99\xf9\x9c\xf6\xc4\xa1\xd5j\x02\x98\xfb\x96{\x93\xae~\x93\xc3\x8aUd\n!\x98'
        b"\xed\x96C\xbe\xc1hpM\x05jb\x05\x1dU\x1e\x89\xa9\xdc\x11bx\xb4\x1cP\xd5\x92bn!\xc9'DZ\x80K\xde^\x9d/\x12\xa9\x03\x90\xbe\xa0\xe8p{\x1c)\xa2\xfb_^\x92\xff+\x82I\xf4\xfaSS\xd0"
        b'\xd7\x97\xc6\xdc00l\xc3\x9e\xba\xfc\xfdA\x989\xe3\x97f\xc2"X\x9a\x9c\x9d\xf3\xa1\xc7\xeb\x7f\xd4\x82\xbe\xc1\xf2\x07|\xb1\xd0|\xdf,\x0b\x10\xd0j\xfd\xf6H\xf5K\xb0\x87\x98\xda\xa3\xc1\xb8p\xd5\x9c\x1dN[v'
        b'\xb8\xf22\xfb}\xa0\xae\x82D\xac&\x01\x9aE\xcf\xe73\x98\xf6\x10\xb6\xa9`)\x9aF\x84\xa1\xdd01J\xbe$(\xca\xa0\x1a\t\x7f\xf7q\x06\x8f\xf6\xeb\x9e\x8dB]\xcd\xc8s\x8c\x8b\xcd\xfd\xf6Lh\xaa\xf6\xed!'
        b'\x84\x99\xaf\x04\xea\x94o!\x959.\xc0\xa130z\x1eECY\xf0.\xc3\xd1\xd2\x16\xc4\xb3\xc8>\xf0\xe6\xc78/@\xfd6\x1ds\x942\xe6\xc4)\xeb]1\xbaq\x11Z\xd8\xe7\x8c\xd1\x9f\xa4\xdb\xcdj\x0c\xe2\xd1'
        b'\x11\xccG9-HK\x96c$]A\x95\xdawe\x83\xb9\xa6u.jC-\x0b\xc4K\x05\xd7\x98\xd0\xcb0/\x13\xc1\xc7\xc0\xa7\x8e\xba\xac\xc6\xd4y:\x9d\xfd\xa1)F\xb2T\xe0\xccQ\xed\xc0 \xe1\x0e\xf7\x02D'
        b'\x98f`\xaahJ\xf5\xa9\x14\x0fG\xc1)\xef4\x17\x86W;ad`v\x08\xd2\xd1\x9f:\x12\xe87\xe1\xfb\xde(@\xdb \xa4\xc9\t\x99\xcf\xf2\xcb8\xbd\x86\x14w\xd4\xf74O\x88~t\xb8\x0c\xb1[1\x0f\xba'
        b'+\xfe\xb5Q\xffv\xb0\xb8\x98\x82h\xf1$\xff_\xdc\x89\xc9i\xbda^\xd5,(!.\xc03\x1a\x06e\x88\xe2\xde\xd2\x7f\xf9\xd3\xac~P\xacn\xc7\x9d\x03$\xf60\x0eJ\xc9`\xec\xd7\nv\x8fS7Y\xff\xa6'
        b"dh\xb5wQtsiI\x0e\x89;2\xd6\x1a\xf9\x87\x88C\xa4\xd3\xa6\xe8\xf6r\xbar\xb7\x97\xae\xb0\xab\x83\xd6)|\x900'z/\x99\xbc\xfe\xf4\xf6\xea\xd8\x0f\xb1\x9d\x8a)\xb7oQ\xad'?j\xa7\x1b\xd1["
        b'})\n10&\x19&/\xa8\xa2k\x07=\x9d.8z3Ch 7(p\x88\xdc\x1e\xcdea\x18l+\xc5\xd8\xcb\xb5Jq\xbd%\x89\xf1$v\xa1\xfe\xd9o\\\xb1\xd2\xf7\x08\xf9#\xb7\x7f\xf0.\xd2cC'
        b'0\x8c\xd0\xd3\xc6%@\x17\xbb\xb2\xc4\xc4X\x9c_eP\x95\xd1\xe8\xb9\x0e\xfe\xc6\x9b\xc2\x1b\x83\x9e@\xcf!tH\xa4\x80\xc2\x8b\xfb\x9c\xe7\x9a-\xbe&\xea)\xcaa\xeb=\xa5d\xa9\x96\xac\xe9\xac\xa2\x8b\x97I6\xb8'
        b'0\xc8\xd0\xdbB\x968c-\x0c\xd2\xae\xbe+%\x1a;\xdfU\xbf\xa3\xbb\xd5\x7f\nb\xf6#\x8c\xcdy\xba\x89\xf0\xc5\x95mP\x19\x93v\x86\xcc\xed05g\xa0\xed\x1cb\x04bAA\x9e\x93*\xdb\x98 *\\\xd1'
        b"\xefJAN\x13#\xaeb\x16p\xb3\xce\xb7\xcf\xe5\x85L(%_\xc4\x0c\xcc\xd0\xcd4\xc8\x87'\xf3\x12\xeb%\xd1\x92\x91\xe3\x13\x17\x03\xf7\xfc\xfb\xad\x13\x1e\n\xd8\xe8\xe1UFu\xb9k\xee\xb6q\xc13Un>\x96"
        b'4\x83]\xc5X\xba\x93!\xf3\xa5i\xf0\xfe\xe3C_\xf8.\xc5\xb4p\x16r\x89;\x1fN\xfe9\x9c\xa1i|1*kE-,4\x1b\xbeel\xe7\x02\xec.\xff\x91\x87X3\xc8^\x9e#J\x98\xd5\xd5\x0c\x1e\x89'
        b'\xddf\xc5k2sD\xdaG\x1d3\xa9\xe3X\x80\x1em\xa2\xf3l"\x07Uk\x1b\xff+\xc6AQ\xcc\x8f>\xb0\x94\xbfw\x08\x9e"}\x13\x1f\x94\x0f\xb7\x85z\x93\x9aC\x80\x8d\xbf\x05\xdb\x9e\xfcbH\xcf\xa5\x9d\x0c'
        b"\xcd9\x10\x1a{'k\x8a1*\xc2\x0f\xa7\xbc\xda\xb5D\x88#\xd1!\xee\xe2\x86\xcb\x80\xf35\xa0\x84K)\xdc\x1b=\xa3\x1f\xa2\xde\x8d`.\xd4\x00.\x83\x07\x12\xaa7\xb0\xc2\xad\x80\xc1\x06Ad\x90\x01\xf3\x9d\x03J"
        b'g\xa2V\xd9\x05\x9e\x07\xabcv|i$\x8fd\xcc\xc9\xb5\xa5x\xa4\xb1\x14\xc80\xd7 k\xc6\xdd\xf4\xcc\xfa\xcc\xa2\xb1\x8f\xf2kx\x93\xfaU\x81\x08\xcf\x8c\x89\xbf1\x82\xe43\xfd\x1f\x03\xb7\xb8\xb8\xf9\xae\xc6i\x8a'
        b'\xbbT\xa6h\xe3\xa7\xbe\x06\x17\x8eM\x91\nB\xc9\x8bXk\xb6;=\x8e\xa1D\xc0M\xe4,,02\xd9\xa6\xc2\x94\xe1\x9eU:\xd2pc\xa5\xf3e\xfc)\xf3\x7f\x86\n\xe7!m\xf6\x0b\xd9\xf3\x861\x00\xe7\xb0\x1b'
        b'n\xbe\x90\xf4\xccN=\xb2\xf0-.\x1c\x91\x1f\x06\xd6q/\xf0\xa3\x8d\xcf\xec\xd5\xc2|\x9f\x07\xb5I\x03p\xe0_\x15\x81\x0e\x90%6\xd3\xbb\x7f0\xbc*X\x15g\xdd[\x08\xf1U\x82\x82\x828P\xc73wN\xb2'
        b'\xbb\xd4\xfa\xb1D\xa9\xd6\x7f\x90\xd3\xd3C\xc42[\x90%\xc1x\xeb\xc0\xcfr\xf1q\x0b\x118\xf7]^\xa3\xc8\xe7\xf7M\x8c"\x0f\xf5\x1e\x19\xb0[\x8a\x1b\xec\x19\x93\xf1\x02#*\x1c\x96\xd7c3\x80\xf6l\xcc\xd7\xf5'
        b'{\xb0\x16\xc3\xac&\x9b\xda~\xf0k\xees\xa4\xe88\xca\xf2\xb4X\x91\xdbJ\xc2\x8ep\xb5\xf1\x1b\xdfr\xab\xe9\xccr\x96.\xbb\x01\xce\x03tU&6\x1f\x90zUf\x1a\x8f\x1f)W\\J&r\xd4\\\xa9m\x93'
        b'\x8bh\x08\xe0\xcbY\xa4\x04J\x045\x8cD\xa6\xa5:\x1aX`Z\xb5D\xa5\xbar\xae\xe9Z\xf3\xee\x8b\x92\xc6R\xdd\xfe\xcb\x06\xaa\xc3\x04[\xecSQ\x14\xafH\xe2b\xb3\xd7\xb0\x17\x9a\x87\xe6R\xc9\xe4-Q\xd0b'
        b'p"\x9a\xbe\xb9\xc2\x07\xcej\xaay\xeaX\xe5N\\j\xe6/\xcc\xa4\x83\x87s\xa1\x00,\xee\x06\xf5\xe0\x82\x07\xf2&y\x1b^\x80\xfb\xac\xa7\xa3\xbb\xba\xefH\'\xad1\xa4p]\x93)\ns\x9e\x9b\xdf\x11\t\x11\xd9'
        b"U\xda_.\xf9\xc5\x8b\x1f\x03\x9f<\xea\xae`\xff\xcc\xea\xf0\xe6'\xbd\xc3[\x12\xa9~t&\xa6&\xc6\xf5\xb0\xf5\xfep`9K+7\xcftn\xbc\xb8bUO`\t~\x9fZ\xab\xf2\xb2\xcc$\xc2$\x9fY*"
        b'\xc1p\xc82\xae\x84H\xc3\x11\xee\x1af=$\x04<\xf2\x81\x8a\xe6(gI\x98\xba\x92\xef?ut\x94t\x1c\xdf\xecF^i\xb7Fe\x17\xa9\xfa\x1b\xff\x9a\x14\xfbE\x02O\x14\xb2z)\x08\xf9S\x92.\xc4&\x9b'
        b'G)\xf4.X\xb1\xbdv\x05w\x96\xf9,\x1cI\xff\xe0\xab-\x1a\x1f!dp\x82\xfa\x18%\x19\xcb\xb0\x150K\x8f\xacC\x08k\xf9\xa7\x07\xec\x1c=Y\xacu\xc4(\x95\x81\xd4\xf3\x8d\xb80\xe0\xea\x83\xcd\xe8\x1e\xe3'
        b"5\xa8\xa8\x86\xf6\x99'\x05\xfd\xf3.\xf6\xf9G\xd7dwe\xb2\xcc\xc4\xf1%\x0f[/\xc6\xc6(\xd7Al\x11\x12M\xa1/\x18\x9b\xdcw\xd4\xa2o\xa2\x1dVz1\x04\xebV\x1c\xcdx\xfa\xa7\xaa|\x8a\x8d\xf7f\x8f"
        b'\xcf\xfd%N\xcda\xa5o\xff#a\x0f\x13"\x8eW\x89\x83\xf3z\xbc/u\x1d\xedx\xdc\x1a\xf3h\xfb\x06L\xbb%]\x04\xa26\xaf\xe9\x1e8I\xf6 7\x96\x9f\x84vv\x82\x0f\xac\x1a\xf6\xce\x7f\xad6YB^'
        b'\xbe\xe6\xcf]\x8f\xc5\x85r\xcbV\x93+m\xef\xe0\xdd\xabiC\xd1\xe6\x92\xc5`\x8f.\x98\xd7|[>\x1f\x93[\xc1\xdb\xaf\x95\x16\xb4C\xac\xeb@_\xc7UA\\!\xfb\x140\xb9\xd3\xad\x12\xd4\xed\x85J\xa7f\xdb'
        b'\x18r2;\\u\xf5\xaa]\x02\x11\xab\x98\\(e\xc8XX\x92Z\xcf/\x98n\x1e\xa7`q\xab\x0cxA\xf5%i\xed\xe4\x7f\xe9|\xa3y\xeaVx\x9b\x8b[\xa9\xcb\xeaS\x0f!\xe6\xd8\xeb\xb4\x84\x14=B\xb2'
        b'8\xb0\xb2\x94\\\xba\xd3\x05\xdb\x01\x06p\xa7X\x1d\xa6+@7\xe3\xd9\x8b\xfb\x1f\xe4<\x93\xbd\xdc\xce\x15<\x11n\xe7NW\xda{5h\xee\xf0S{T\xd6\x8a\xf6\xab\xc7`\x86Z\xf9)&\xc4\x90P\xa0o\xacP'
        b'4\xe7$\x0f\xc5\xf6\xfe\xff\xc8\xf0\xe5\xc1 \xa9\xa4>6K\xa1\x07\x90\x0b\xe8\x84\x19\x97\xcdA\xb3E\x14w"\xfe\x03\x80\xa9\xf3\x8b\x91\xb8\xc4>\x0b}\x19\xa4\xcf\x90\x02F\xae\xd7\x12H|\x13\xbel\x12g\x87\xd2\xda'
        b'w\xdc~\xfd\rB\xe1\x80\xd1Z\xe2\xbd8D\xd2\xb9\xcf\x19|\xb9\x83\x92+\xa1\xf9|\xd4\xe0\xde\x98{\xe4_^\x01w\xbf\xeb\x99q\xf66\xc0\xca\xa2>\x93\xa5\x80\xaf\xa7\xda\xe0\x13cp\x1b<\x0f\xed\xb2n\x087'
        b'J\r\xc7\xb6g\xf6\xafDZ\x83\x90V\x0c\xfb!\xba\xa3R\x7f\xdb\x02\x9c<\xe0\xb3{\xd3\xef1\x08_X\x9ay\x8eH3T\x96\x99+~\xe1"\xcb}\x04\xacr\x06\x12.\xe0\xb9\xf7?+\xc6\xcf\x95\x9et\x88:'
        b'sO\x18\x08c\xed\x0f\x8bT0qN3,?\xa3\x84\xb0\xd0\x80\xb4#\x04\x8e\x19l\x05m\x8b\xdf\x9cHxL\x01\x85r\x80,1g*]a\xa6=y9\x86\xd1\xd3dM\x88\xdat\xa0\xc1\xf9\x92\xdb+\xfb\xc4'
        b'\x0c\xfd\xf7\xb9OpU\xc2y\x84\xfawR\xcbf\x10\xbfgm\xf3!\x9f\xf3\xd2\xd1YK\xa2|p\x90\xe2I\xb2\x80\xc2\xd9n\xeb\x10ec\xba\x86\xb5\xeftG2\xbc\xd0\x02{\xc3\xf9-WK,\x08:&el'
        b"\\ux&q\xd0\xea2\xd8\x98\xacA\t\x05\xdd-`\x06\xa0\x92\x1f\xb7\x7fQ\xe2\xb0\xff\x89\xbeX\x02\x84N\xe4\xb9!\x83+\xd1\x95>\x8aX\xdb\xc0\xbf\x81\x03\xb0\x9a\x96'\xa4\x9d\x89?\\\x07\x08\x0c~O\xb9\x84"
        b'D7\xa1+\xd7o\x14\xa2\xca\x15\x9d\xf0\xd6\xfb\xd7\x17\x8br\xc16oG\xd9K\xb6\xe7\xf5q\x98\xb0\x07\x02\xba\t\x9d\x05\xc5\xdb\xd0\x92\xbc\xdd\xb4\xb4@\xcd\x94\x0el\xddF/9_5\xf6Q\xfe\x81\x0f\x8847E'
        b"\x15\xa13\xef\xa1\xc1\x99\xb6w\xfa.\xd9\xad\x02i\x87\xb8\xeb\x03\x9b31\xa7\x15\xd1L\xdb\xbc\x17\x92\x86\x17\xd5X\xab\x18\xba'm\xf4\r=5h\xd36\x89\x80\xf8\xd2\xb7h\xb1\x90-\x03@\x13\xb2\x9c@r\x9b!"
        b'\x03?Y2\xd9\xb1RdX$\xc7\xfb\xbb(\xed\xa3\x1f\x0b\x87\x866\xdf[\xf9\xab\x7f\xf7-\xa9\xeb\xfa,\x98\xd5\x8f\xb5\xe7\x8cj\x1e\xec\xb4\x9c#\xeac\xcfx/YDU\xee\xad3\xce\xd116\xaa\x02H\xaf\xe2'
        b'<\x1cbb%\xa5\xcb\x11\xf4\xb6\xe7\xaf\xa4\xa1\x82\x1a_\x02\x8d\xf7\x95\xfd\x88+n\x1d\x8aCx[\x13\x8c\x8b\xa0\x90\x84\xf1\xdat9T(\xbe\xeaD~2qQ\xfe\xd30\x8c\x90v\x8b\xee\xd8\x15\xdfe\x80\xf2['
        b'\\\xed\xc6}\xc3\rc\xd1LOTQ\x85(\xe0\x8c\xf9\x1cq\xdd\xd1\xfb:b\x8eCU\xff\x0be\xc0Z\x1d\xf4\xb4\xb4\x9b\x11\xa2]\xf7"\t6\x1f\x9a-\x98\x7fY\xb6;\x82\x8e\xdc\xdf_\xa7\x9b2\x15D\xc6\xd7'
        b'm\xe0_\x07m\xf8P!\xe4^\xbaR\x92\xa4t\xc9>qR\x88\xb8\xe7z\xd0\xc8g\xccElxIK\xf0\xae\x9fe\xd4\xea\xd7\xbch\xec\xe1\x08!\xe5\x80\xa3\xff*\x9fJ\x9c\x88\x1e\xa9^94\x97;\xf2\xf0E'
        b'\xd41\n\x89&\xb9\x14=Pk\xb4P\xd1`\x16\x06C\xed\n<\xe7[\xca=Fv\x80)\x85{`\xd7`b\xcaqG\x14\xd8\xfb\x94<G\x8f%\xe2\xbd\x9c!\xa5\xd0\xcbWv\xa8\xe9#\xd3\xf7o\x0c\xc9\xa7\x1d'
        b'6\xfd]g=\xaa\x87\xac\xed4\x10\t\x85jyl\xce\xb4\x8bfK\x11\x7fO<g/\xf2\xfdq\x87BHYf5H;dGj\x8e\xc9E\xbc\x8d\x03(J\x18I\xf6\x1f"\xe5@:V\x1a\x058\xdf\xc3\xc2'
        b'\xf4\x7f\x07t\x00\x95,O\x02O\xcb\x8fH\xea\x9c\xf1\tZ\xb2\xfc@#\xd2zp\xbc\\\xfb\xa20\x0cGQ\x08\xadf\x94\xb2\xcb\x1b\xa2\x97\x1c\xd2\x92\xa6n\xc5rO\x80\xec\xc3\xd51iaq\xe1\xd6\xc4g\x19E'
        b'&\x9d_g\xa2h\x1c\x8a\xd1/\xd0\ro\x85[\xe7\xfa\xbf\x87\xf6\xfbRw#?\xfevI#M\xc2\xb3\xfd\xdc\xd4\t\xd5~\xed9\x8e\xcb>\xe8l\xbdM\x95YD\x8f\xf6m\xfa\xb0"\x92\xb1\xa9Xx\x07\xbc\x1b'
        b'CE<\x9f\xa1r\xd5D\xd9T\xf8\x8ccWs\xa6Y\xfd\xd2\xe7 W\x03\x1f0\xda\xaf\xb1\xf2\xd3\xdcC\xe7\xfbE\xf9\x03g\xe7\x07dA\x88\x83\x17(+\x988k:\x81V`\x01\xde}\x1f/\xb64>\xa6\x92'
        b"\x0e\xfd-<&\xf1\xc9\xa4\x1e+i)\x0c\xf2}\xe6Q\xf1\x89\xd6{\xb8\xf7q.\x11\x1f\xe4\xdcI~\xef\x11\xc3\xd58J\xb2-_A\xa8\xaa\x92\x7fO\x80J\xca\xe5\xe6>\xbe\x87}\x0e'\xacHD\x9e\x17*\x11"
        b'\xf7w\xfcmZX\xf7\xf0\x8eP:D\x17#X\x80\xd1~0\x98sk+\x05\xa9/\xa6F\xf8M\xeb\x86\xb0\x8d\xe0UW\xce\xcar\xa6\xb3\xd3\t!\xe30v\xcbq\x0f]\xd8e,\x11\x8a\xd3\xbca\x02\xf6b\x9e'
        b'\r\xd9\xe7\xa4Mmj\xfa\xff/Nt\x04G\xb5\xe2\xd7(\x9c\xb4\x95\xbe!\x08C\xd7T\xd2\x7fQ\xa2\xefm\xb70\xc6W\x16\x9bz\xee\x03\r\x88\xf4\x169\xb3~i\xbc\x80T\xcd\xda\x96g\xf9\xc3\xf8\xaeo.\xa7'
        b'\x90\xc3\t\xf1\xc9\xd1\xd7\xe15m\xd0f\x08\xed\x05\xc0\x94U\x1f\xf8\xa1\xf5jM\xbf\xee\xf0\x9d\x0et\xb7\xa6-,#.\x1aS\x1a,\xb5\xea\xd9n\x1b\xea\x01\xaay\x80^}\x98lY\xca\xce\x14_K\xbe\xf1<>'
        b'O\xc3Di=\xdf\xb7N\xbco4\xf0\x82\x1f\xe97\xda@e#,\xf0\xf0\x0f\x8fW\x16k \xc5\x10\x07\xb7N\x15\xc8v\xa7T\xd2oe\xfekN\xc2\n\x99\x8e\xd1\xbd\xc9\x10U\xc5o\xb4\xcbu\xc93\xcd\x08\xf2'
        b'\x10&\xa0\x04\xb5T\n\xc7\xd9\xa1\xc3\xc4\xf5\xd5\xd8Q\xb1 \x1c\xe0\xafc\xbb\xd2\xd5\x17 \x8f\x87\xc7\xb6\xedfuJ\xd1 \xa8PD%\xc5<\xbc\x8d\xf5\xbe\xee\x9c\xbc\xb5#\xc9\xf0<\x83\xcf*\x944\x9b\xa5\x1b\xd6'
        b' \xcf\x195o\xb6\xd1\xaf\x9bBXk\x8d\x85\xb2\xd9C\xa2fc\xed\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name'
        b'__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08'
        b'\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
